#........................................................................................................
### ~~ R CODE TO CREATE TIME SERIES OF DISTRICT DATA FOR SOMALIA DEATH TOLL ANALYSIS (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (October 2012)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
#setwd("C:/Users/Francesco/Desktop/Analysis")
setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis") #office


#.........................................................................................
### Create time series of Somalia/Puntland/Somaliland districts

year <- seq(2006, 2012, 1) #sequence of years
month <- seq(1, 12, 1) #sequence of months
districts <- read.csv("districts.csv") # districts

td <- expand.grid(districts[, "district"], month, year)
colnames(td) <- c("district", "m", "y")

td <- merge(td, subset(districts, select=-c(notes) ), by="district")

# sort data
td <- td[order(td[, "district"], td[, "y"], td[, "m"]), ]

# add month from 1 to end of time series for each district (needed later ro merging into survey metadata)
td[, "tm"] <- rep(seq(1, length(year)*length(month), 1), nrow(districts) )

#.........................................................................................
### Add UNDP population data per district, projected forward from Jun 2005 (UNDP reference time point) assuming a 3% yearly growth rate

# months between start of time series and UNDP measurement (should be -10)
t_undp <- (2005 - year[1]) * length(month) + 6 - month[1]

# project forward
td[, "pop_undp_proj"] <- td[, "pop_undp_total"] * ( (1 + 0.03/12)^(td[, "tm"] - t_undp) )
td[, "pop_undp_proj_urb"] <- td[, "pop_undp_urban"] * ( (1 + 0.03/12)^(td[, "tm"] - t_undp) )

   
#.........................................................................................
### Add and smooth Consumer Price Index data

# read data
cpi <- read.csv("cpi_data.csv") # CPI data by district

# merge CPI data with district time series
td <- merge(td, cpi[, c("district", "y", "m", "cpi")], by=c("district", "y", "m") , all.x=TRUE)

# create column to hold smoothed values
td[, "s_cpi"] <- NA

# for each district...
for (i in c(unique(as.character(td[, "district"])) ) ) {

	# capture relevant data from district i 
	td.i <- subset(td, district==i)[, c("tm", "cpi")]
	
	# if there are no CPI data for the district...
	if (length(na.omit(td.i[, "cpi"]) ) == 0 ) {
		
		# no smoothing; return a series of NA values
		td.i[, "s_cpi"] <- NA
		
		# update dataset
		td[ match(i, td[, "district"]) : (match(i, td[, "district"]) + nrow(td.i) - 1) , "s_cpi"] <- td.i[, "s_cpi"]	
		
		}
	else	
	{

		# omit missing values
		td.i.clean <- na.omit(td.i)
		
		# determine when data start and end
		t_start <- min(td.i.clean[, "tm"])
		t_end <- max(td.i.clean[, "tm"])		
		
		# smooth variable and extrapolate (predict) missing ones within the period of data availability
		sm <- data.frame("tm"    <- seq(t_start, t_end, 1),
		                 "s_cpi" <- predict( smooth.spline(td.i.clean[, "tm"], td.i.clean[, "cpi"], spar = 0.5) , seq(t_start, t_end, 1) )["y"]
						)
		colnames(sm) <- c("tm", "s_cpi")
		
		# merge smoothed values with original time series
		td.i <- merge(td.i, sm, by="tm", all.x=TRUE)

		# update dataset
		td[ match(i, td[, "district"]) : (match(i, td[, "district"]) + nrow(td.i) - 1) , "s_cpi"] <- td.i[, "s_cpi"]		
		
		# inspect result of smoothing
		plot(td.i[, "tm"], td.i[, "cpi"], main = i)
		lines(td.i[, "s_cpi"], col="blue")
		#Sys.sleep(1)
	}

	}


	   
#.........................................................................................
### Add ACLED conflict incidents data

# read data
acled <- read.csv("conflict_incidents.csv") # conflict events from ACLED dataset

# merge ACLED dataset with district time series
td <- merge(td, acled[, c("district", "y", "m", "n_incidents")], by=c("district", "y", "m") , all.x=TRUE)

# transform NA values to 0 events
td[, "n_incidents"] <- ifelse(is.na(td[, "n_incidents"])==TRUE, 0, td[, "n_incidents"] )

				   
#.........................................................................................
###Add information on WFP presence (mostly absent in Southern sector after Dec 2009 with the exception of Mogadishu)

f.td.wfp <- function(f.td) {

	if( (f.td[["sector"]] == "S") & (f.td[["region"]] != "Banadir") & (as.numeric(f.td[["y"]]) > 2009) ) return("no") else return("yes")

}

td[, "wfp_present"] <- apply(td, 1, f.td.wfp)


#.........................................................................................
### Add ToT indices

# add market weights
markets <- read.csv("markets.csv") # markets

for (i in 1:3) {
	
	mar <- markets[, c("market", "market_wt")]
	colnames(mar) <- c(paste("market", i, sep=""), paste("market", i, "_wt", sep="") )
	td <- merge(td, mar, by=paste("market", i, sep=""), all.x=TRUE )

}

# sort data
td <- td[order(td[, "district"], td[, "y"], td[, "m"]), ] 

# add ToT data						   
prices <- read.csv("market_data_analysis.csv")

# compute ToT values across each stratum, for each month and year
f.td.tot <- function(f.td, f.prices) {

	# district month and year being analysed
	m_ser <- as.numeric(f.td[["m"]])
	y_ser <- as.numeric(f.td[["y"]])	
	
	# calculate weighted mean ToTs
	return( c(
				#AToTw
				weighted.mean( c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["AToTw_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["AToTw_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["AToTw_comp"] )						  
								) ,
							   c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["market_wt"] )
								) ,
							   na.rm=TRUE
							  ) ,
				#AToTg
				weighted.mean( c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["AToTg_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["AToTg_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["AToTg_comp"] )						  
								) ,
							   c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["market_wt"] )
								) ,
							   na.rm=TRUE
							  ) ,
				#RToTw
				weighted.mean( c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["RToTw_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["RToTw_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["RToTw_comp"] )						  
								) ,
							   c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["market_wt"] )
								) ,
							   na.rm=TRUE
							  ) ,
				#RToTg
				weighted.mean( c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["RToTg_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["RToTg_comp"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["RToTg_comp"] )						  
								) ,
							   c( as.numeric(subset(f.prices, market == as.character(f.td[["market1"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market2"]]) & m == m_ser & y == y_ser)["market_wt"] ) ,
								  as.numeric(subset(f.prices, market == as.character(f.td[["market3"]]) & m == m_ser & y == y_ser)["market_wt"] )
								) ,
							   na.rm=TRUE
							  )
			  )		
		   )

}

td[, c("AToTw", "AToTg", "RToTw", "RToTg")] <- t (apply(td, 1, f.td.tot, prices) )

	


#.........................................................................................
###Save dataset

td <- td[, c("location", "region", "sector", "district", "y", "m", "tm", "pop_undp_total", "pop_undp_urban", "pop_undp_proj", "pop_undp_proj_urb",
			 "market1", "market1_wt", "market2", "market2_wt", "market3", "market3_wt", "AToTw", "AToTg", "RToTw", "RToTg",
			 "cpi", "s_cpi", "n_incidents", "wfp_present")]

# write to file
write.csv(td, "tseries_districts.csv" , row.names=FALSE)


