#..........................................................................................
### ~~ R CODE TO PREPARE STATISTICAL MODELLING FOR SOMALIA DEATH TOLL ANALYSIS (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (November 2012)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis")

# read data
valid <- read.csv("results_mortality_validation.csv") # results of reanalysis of mortality datasets
surveys <- read.csv("survey_metadata.csv") # survey metadata
td <- read.csv("tseries_districts.csv") # district time series
year <- seq(2006, 2012, 1) #sequence of years
month <- seq(1, 12, 1) #sequence of months


#.........................................................................................
### Add results from mortality survey re-analysis, define estimates for further analysis

# merge results of mortality re-analysis with survey metadata
surveys <- merge(surveys, subset(valid, select=-c(X, survey_y, survey_m, location1, livelihood)), by="survey_id", all.x=TRUE)

# if a reanalysed result is available, adopt that one, else adopt the FSNAU estimate
surveys[, "cdr_est_model"]  <- ifelse(is.na(surveys[, "cdr_lshtm_est"])== FALSE , surveys[, "cdr_lshtm_est"], surveys[, "cdr_est"] )
surveys[, "cdr_lci_model"]  <- ifelse(is.na(surveys[, "cdr_lshtm_lci"])== FALSE , surveys[, "cdr_lshtm_lci"], surveys[, "cdr_lci"] )
surveys[, "cdr_uci_model"]  <- ifelse(is.na(surveys[, "cdr_lshtm_uci"])== FALSE , surveys[, "cdr_lshtm_uci"], surveys[, "cdr_uci"] )

surveys[, "u5dr_est_model"] <- ifelse(is.na(surveys[, "u5dr_lshtm_est"])== FALSE , surveys[, "u5dr_lshtm_est"], surveys[, "u5dr_est"] )
surveys[, "u5dr_lci_model"] <- ifelse(is.na(surveys[, "u5dr_lshtm_lci"])== FALSE , surveys[, "u5dr_lshtm_lci"], surveys[, "u5dr_lci"] )
surveys[, "u5dr_uci_model"] <- ifelse(is.na(surveys[, "u5dr_lshtm_uci"])== FALSE , surveys[, "u5dr_lshtm_uci"], surveys[, "u5dr_uci"] )

# check differences between FSNAU and LSHTM estimates (assume absolute difference of > 0.2 in CDR or U5DR is of concern)
surveys[, "discordance_cdr"] <- ifelse(abs(surveys[, "cdr_lshtm_est"] - surveys[, "cdr_est"] ) > 0.2, "yes", "no")
surveys[, "discordance_u5dr"] <- ifelse(abs(surveys[, "u5dr_lshtm_est"] - surveys[, "u5dr_est"] ) > 0.2, "yes", "no")


#.........................................................................................
### Check plausibility of confidence intervals

# compute difference between upper and lower interval of log rate estimate (should be close to 0)
surveys[, "cdr_ci_symmetry"]  <- (log(surveys[, "cdr_uci_model"] / 10000) - log(surveys[, "cdr_est_model"] / 10000) ) / 1.96 -
							     (log(surveys[, "cdr_est_model"] / 10000) - log(surveys[, "cdr_lci_model"] / 10000) ) / 1.96

surveys[, "u5dr_ci_symmetry"] <- (log(surveys[, "u5dr_uci_model"] / 10000) - log(surveys[, "u5dr_est_model"] / 10000) ) / 1.96 -
							     (log(surveys[, "u5dr_est_model"] / 10000) - log(surveys[, "u5dr_lci_model"] / 10000) ) / 1.96

								
# decide that there is a problem (non-symmetrical CIs in log metric) for CDR if absolute value of above difference is >0.10
surveys[, "cdr_ci_correct"]  <- ifelse( abs(surveys[, "cdr_ci_symmetry"]) < 0.10, "yes", "no")							
surveys[, "u5dr_ci_correct"] <- ifelse( abs(surveys[, "u5dr_ci_symmetry"]) < 0.10, "yes", "no")							

							
#.........................................................................................
### Compute a weight for each mortality survey

## compute standard errors of the log death rate
surveys[, c("ln_cdr_se", "ln_u5dr_se")] <- NA

for (i in 1:nrow(surveys) ) {
	
	# if survey is exhaustive (i.e. no confidence intervals)... (see report appendix for details)
	if ( (is.na(surveys[i, "cdr_uci_model"]) == TRUE) & (is.na(surveys[i, "cdr_est_model"]) == FALSE) ) {
			
			surveys[i, "ln_cdr_se"]  <- ifelse(is.na(surveys[i, "n_people"])==TRUE, 1 / sqrt(450 * 5.4 * surveys[i, "cdr_est_model"] * 90 / 10000) ,
												1 / sqrt(surveys[i, "n_people"] * surveys[i, "cdr_est_model"] * 90 / 10000)	)
			surveys[i, "ln_u5dr_se"]  <- ifelse(is.na(surveys[i, "n_people"])==TRUE, 1 / sqrt(450 * 5.4 * 0.25 * surveys[i, "u5dr_est_model"] * 90 / 10000) ,
												1 / sqrt(surveys[i, "n_people"] * 0.25 * surveys[i, "u5dr_est_model"] * 90 / 10000)	)
		
		}

	# if survey is cluster/PPS...
	if ( (is.na(surveys[i, "cdr_uci_model"]) == FALSE) & (is.na(surveys[i, "cdr_est_model"]) == FALSE) ) {
		
			surveys[i, "ln_cdr_se"]  <- ( log(surveys[i, "cdr_uci_model"] / 10000) - log(surveys[i, "cdr_est_model"] / 10000) ) / 1.96			
			surveys[i, "ln_u5dr_se"]  <- ( log(surveys[i, "u5dr_uci_model"] / 10000) - log(surveys[i, "u5dr_est_model"] / 10000) ) / 1.96
		
		}

	}

	
## correct log rate SE of surveys that have an implausible 95%CI (i.e. one that is asymmetric in the log metric) - see report appendix

#Calculate multiplying factors to use when guesstimating log rate SE, using LSHTM reanalysed results
adj.cdr  <- mean (subset(surveys, survey_design=="cluster, pps" & cdr_ci_correct=="yes" & is.na(deaths_lshtm)==FALSE )[, "ln_cdr_se"] * 
				  sqrt (subset(surveys, survey_design=="cluster, pps" & cdr_ci_correct=="yes" & is.na(deaths_lshtm)==FALSE )[, "deaths_lshtm"])  )

adj.u5dr <- mean (subset(surveys, survey_design=="cluster, pps" & u5dr_ci_correct=="yes" & is.na(deaths_u5_lshtm)==FALSE )[, "ln_u5dr_se"] * 
				  sqrt (subset(surveys, survey_design=="cluster, pps" & u5dr_ci_correct=="yes" & is.na(deaths_u5_lshtm)==FALSE )[, "deaths_u5_lshtm"]) ) 


for (i in 1:nrow(surveys) ) {
	# for each survey that has problems with the reported CDR 95%CI...
	if (is.na(surveys[i, "cdr_ci_correct"]) == FALSE & surveys[i, "cdr_ci_correct"] == "no") {
		#if the survey does contain information about the total number of deaths...
		if (is.na(surveys[i, "deaths"]) == FALSE) {

			surveys[i, "ln_cdr_se"]  <- (1 / sqrt(surveys[i, "deaths"]) ) * adj.cdr			
			
			}
		#...otherwise if the n of deaths is unknown, it is calculated based on assumptions about sample size and mean household size:
		else {
			
			surveys[i, "ln_cdr_se"]  <- (1 / sqrt(surveys[i, "cdr_est_model"] * 90 * 678 * 5.4 / 10000) ) * adj.cdr
		
			}
		}
	# for each survey that has problems with the reported U5DR 95%CI...
	if (is.na(surveys[i, "u5dr_ci_correct"]) == FALSE & surveys[i, "u5dr_ci_correct"] == "no") {
		#if the survey does contain information about the total number of deaths under 5y...
		if (is.na(surveys[i, "u5deaths"]) == FALSE) {

			surveys[i, "ln_u5dr_se"]  <- (1 / sqrt(surveys[i, "u5deaths"]) ) * adj.u5dr			
			
			}
		#...otherwise if the n of deaths under 5y is unknown, it is calculated based on assumptions about sample size and mean household size:
		else {
			
			surveys[i, "ln_u5dr_se"]  <- (1 / sqrt(surveys[i, "u5dr_est_model"] * 90 * 678 * 5.4 * 0.25 / 10000) ) * adj.u5dr
		
			}
		}

	}	

	
## Compute survey weights	

	# compute two alternative sampling weights (Weight 1 = 1 / variance of log rate = 1 / SE^2 ; Weight 2 = 1 / SE of log rate)
	surveys[, "cdr_sampling_weight1"]  <- 1 / (surveys[, "ln_cdr_se"] ^2 )
	surveys[, "cdr_sampling_weight2"]  <- 1 /  surveys[, "ln_cdr_se"]			
	surveys[, "u5dr_sampling_weight1"] <- 1 / (surveys[, "ln_u5dr_se"] ^2 )
	surveys[, "u5dr_sampling_weight2"] <- 1 /  surveys[, "ln_u5dr_se"]				
		
	# compute overall weight as product of quality weight and sampling weight
	surveys[, "cdr_survey_weight1"] <-  surveys[, "cdr_sampling_weight1"]  * surveys[, "quality_weight"]	
	surveys[, "u5dr_survey_weight1"] <- surveys[, "u5dr_sampling_weight1"] * surveys[, "quality_weight"]	

	surveys[, "cdr_survey_weight2"] <-  surveys[, "cdr_sampling_weight2"]  * surveys[, "quality_weight"]	
	surveys[, "u5dr_survey_weight2"] <- surveys[, "u5dr_sampling_weight2"] * surveys[, "quality_weight"]	


#.........................................................................................
### Define eligibility of mortality and anthropometry data for analysis

# surveys eligible for mortality analysis if there is a CDR point estimate and the quality weight is non-zero
surveys[, "eligible_mortality"] <- ifelse(is.na(surveys[, "cdr_est_model"]) == TRUE | surveys[, "quality_weight"]==0, "no", "yes")

# surveys eligible for anthropometry if there is a GAM estimate (WHZ or MUAC based) and the quality weight is non-zero
surveys[, "eligible_anthropometry"] <- ifelse( ( is.na(surveys[, "gam_whz_who"]) == TRUE & is.na(surveys[, "gam_whz_nchs"]) == TRUE &
                                                 is.na(surveys[, "gam_muac"]) == TRUE ) | surveys[, "quality_weight"]==0, "no", "yes")
	

#.........................................................................................
### Add ACLED conflict incidents data by district

# function that computes cumulative incident rate over a time window centred at any given month prior to the mid-point of the mortality survey recall period and with any given width in months
f.surveys.conflict <- function(f.surveys, f.td, f.tlag, f.twindow, f.year, f.month) {

	# cumulative events and person-time denominators
	events <- 0
	ptime  <- 0

	# calculate mid-point of survey recall period (month in time series)
	t_mid <- (as.numeric(f.surveys[["y_survey"]]) - f.year[1]) * length(f.month) + as.numeric(f.surveys[["m_survey"]]) - floor(as.numeric(f.surveys[["recall_months"]]) / 2)

	
	# calculate start end end time point of time window for event rate summation
	t_start <- t_mid - f.tlag - ceiling( (f.twindow -1) / 2)
	t_end   <- t_mid - f.tlag + ceiling( (f.twindow -1) / 2)

	# for each district...
	for (i in f.surveys[c("district1", "district2", "district3", "district4", "district5", 
	                      "district6", "district7", "district8", "district9", "district10", "district11")]
		) {
			#which district?

			dis <- as.character(i)
	
			# if district is not null...
			if (dis != "") {

				# add events and person-time from that district to the cumulative total			
				events <- events + sum(subset(f.td, district == dis & tm >= t_start & tm <= t_end)[, "n_incidents"] , na.rm=TRUE)
				ptime  <- ptime  + sum(subset(f.td, district == dis & tm >= t_start & tm <= t_end)[, "pop_undp_proj"], na.rm=TRUE)

				}
		  }
	
	# return event rate per 100,000 person-months

	return(events * 100000 / ptime)

	}


# specify lags considered plausible and window of moving averages
tlag <- c(0, 3) # either no lag or delayed effect of conflict 3 months later
twindow <- 3 # 3 = same as duration of recall period

# compute event rate for each survey and for each plausible lag	
for (i in tlag) {

	surveys[ , paste("rate_incidents_lag", i, sep="")] <- apply(surveys, 1, f.surveys.conflict, td, i, twindow, year, month)	

}	
	

#.........................................................................................
### Add ToT variables based on district time series

# function that computes mean ToT over a time window centred at any given month prior to the mid-point of the mortality survey recall period and with any given width in months
f.surveys.tot <- function(f.surveys, f.td, f.tlag, f.twindow, f.year, f.month) {

	# calculate mid-point of survey recall period (month in time series)
	t_mid <- (as.numeric(f.surveys[["y_survey"]]) - f.year[1]) * length(f.month) + as.numeric(f.surveys[["m_survey"]]) - floor(as.numeric(f.surveys[["recall_months"]]) / 2)
	
	# calculate start end end time point of time window for ToT averaging
	t_start <- t_mid - f.tlag - ceiling( (f.twindow - 1) / 2)
	t_end   <- t_mid - f.tlag + ceiling( (f.twindow - 1) / 2)

	# output
	out <- c(NA, NA, NA, NA)
	
	# for each ToT index...
	for (i in c("AToTw", "AToTg", "RToTw", "RToTg") ) {

		# district values to be averaged
		x <- c()
		# weights
		w <- c()
		
		# for each district...
		for (j in f.surveys[c("district1", "district2", "district3", "district4", "district5", "district6", "district7", 
							  "district8", "district9", "district10", "district11", "backup_district1", "backup_district2")]
			) {
				#which district?
				dis <- as.character(j)
		
				# if district is not null...
				if (dis != "") {

					# add ToT values and their weights to list
					x <- c(x, mean(subset(f.td, district == dis  & tm >= t_start & tm <= t_end)[, i], na.rm=TRUE) )
					w <- c(w, as.numeric(subset(f.td, district == dis  & tm == (t_mid - f.tlag) )[, "pop_undp_proj_urb"] ) )
					
					}
			  }
		
		#compute weighted mean of all districts for this ToT index
		out[match(i, c("AToTw", "AToTg", "RToTw", "RToTg") )] <- weighted.mean(x, w, na.rm=TRUE)

		}	

	return(out)
	
	}

# specify lags considered plausible and window of moving averages
tlag <- seq(1, 6, 1)
twindow <- 3 # 3 = same as duration of recall period


# compute ToT indices for each survey and for each plausible lag	
for (i in tlag) {

	surveys[ , c(paste("AToTw_lag", i, sep="") , paste("AToTg_lag", i, sep=""), paste("RToTw_lag", i, sep=""), paste("RToTg_lag", i, sep=""))] <- 
		t(apply(surveys, 1, f.surveys.tot, td, i, twindow, year, month)	)
	
	# attribute livelihood-specific RToT
	surveys[, paste("RToT_liv_lag", i, sep="")] <- ifelse(surveys[, "livelihood"] == "pastoral",
	                                                      surveys[, paste("RToTg_lag", i, sep="")], surveys[, paste("RToTw_lag", i, sep="")]
														 )

}	


	
						   
#.........................................................................................
###Add information on WFP presence

# function that computes whether WFP was mostly present over a time window centred at any given month prior to the mid-point of the mortality survey recall period and with any given width in months
f.surveys.wfp <- function(f.surveys, f.td, f.tlag, f.twindow, f.year, f.month) {

	# calculate mid-point of survey recall period (month in time series)
	t_mid <- (as.numeric(f.surveys[["y_survey"]]) - f.year[1]) * length(f.month) + as.numeric(f.surveys[["m_survey"]]) - floor(as.numeric(f.surveys[["recall_months"]]) / 2)
	
	# calculate start end end time point of time window for determining whether WFP was mostly present
	t_start <- t_mid - f.tlag - ceiling( (f.twindow - 1) / 2)
	t_end   <- t_mid - f.tlag + ceiling( (f.twindow - 1) / 2)
	
	# count of district-months with WFP presence during time window
	wfp <- 0
	
	# number of potential district-months of WFP presence
	wfp.pot <- 0
	
	# for each district...
	for (i in f.surveys[c("district1", "district2", "district3", "district4", "district5", 
	                      "district6", "district7", "district8", "district9", "district10", "district11")]
		) {
			#which district?
			dis <- as.character(i)
			
			# add district-months with WFP presence to the cumulative total
			wfp <- wfp + nrow(subset(f.td, district == dis & tm >= t_start & tm <= t_end & wfp_present=="yes") )
			
			# add potential district-months to the cumulative total
			wfp.pot <- wfp.pot + nrow(subset(f.td, district == dis & tm >= t_start & tm <= t_end) )			
			
		  }
	
	# return "yes" if the cumulative districts-months with WFP are >= 1/2 of the total district-months
	if ( (wfp / wfp.pot) >= 0.5 ) return("yes") else return("no")

	}


# specify lags considered plausible and window of moving averages
tlag <- seq(0, 6, 1)
twindow <- 3 # 3 = same as duration of recall period

# compute WFP presence for each survey and for each plausible lag	
for (i in tlag) {

	surveys[ , paste("wfp_present_lag", i, sep="")] <- apply(surveys, 1, f.surveys.wfp, td, i, twindow, year, month)	

}	


#.........................................................................................
### Add mid-point month of recall period (to represent season)

# function that computes mid-point of survey recall period
f.surveys.recall <- function(f.surveys) {

	# calculate mid-point month and year of survey recall period
	m_sur  <- as.numeric(f.surveys[["m_survey"]])
	y_sur <- as.numeric(f.surveys[["y_survey"]])
	goback <- floor(as.numeric(f.surveys[["recall_months"]]) / 2)
	
	return( c( ifelse(goback >= m_sur , m_sur - goback + 12 , m_sur - goback) ,
	           ifelse(goback >= m_sur , y_sur - 1 , y_sur)
             )	
	      )
		
	}

surveys[ , c("m_mid", "y_mid")] <- t( apply(surveys, 1, f.surveys.recall) )



#.........................................................................................
### Decide whether survey was done in a period of food security crisis or not (baseline method 1)

# define baseline method 1 as the average RToT specific to the livelihood of the sampling frame having been >=1 during the recall period AND the 9 months before the start of the recall period
surveys[, "baseline_tot"] <- ifelse( (surveys[, "RToT_liv_lag0"] >= 1) & (surveys[, "RToT_liv_lag3"] >= 1) &
                                     (surveys[, "RToT_liv_lag6"] >= 1) , "yes", "no" )

	# number of baseline surveys by livelihood type
	table(subset(surveys, location1=="Somalia" & eligible_mortality=="yes")$baseline_tot,
	      subset(surveys, location1=="Somalia" & eligible_mortality=="yes")$livelihood)
									 							 
	# boxplot graph for report
		# general parameters
		windowsFonts(Calibri=windowsFont("Calibri"))
		par(family="Calibri")
		par(mfrow=c(1,2), mar=c(2,4,1,1)+0.1, oma=c(1,1,1,1))
		
		# CDR
		stripchart(cdr_est_model ~ livelihood, data=subset(surveys, location1=="Somalia" & baseline_tot=="yes" & eligible_mortality=="yes"),
				   vertical=TRUE, group.names=c("agro-pastoral", "IDP", "pastoralist", "riverine", "urban"), ylab="deaths per 10,000 person-days",
				   pch=1, col="blue", main="crude death rate", cex.main=1)
		
		# U5DR
		stripchart(u5dr_est_model ~ livelihood, data=subset(surveys, location1=="Somalia" & baseline_tot=="yes" & eligible_mortality=="yes"),
				   vertical=TRUE, group.names=c("agro-pastoral", "IDP", "pastoralist", "riverine", "urban"), ylab="deaths per 10,000 child-days",
				   pch=1, col="blue", main="under 5 years death rate", cex.main=1)
				   
		# save plot
		savePlot("graph_baseline_method1.wmf",type="wmf") 			

#.........................................................................................
### Decide whether survey was done in a period defined as phase 1 or 2 by IPC criteria (baseline method 2)


	# number of baseline surveys by livelihood type
	table(subset(surveys, location1=="Somalia" & eligible_mortality=="yes")$baseline_ipc,
	      subset(surveys, location1=="Somalia" & eligible_mortality=="yes")$livelihood)
									 							 
	# boxplot graph for report
		# general parameters
		windowsFonts(Calibri=windowsFont("Calibri"))
		par(family="Calibri")
		par(mfrow=c(1,2), mar=c(2,4,1,1)+0.1, oma=c(1,1,1,1))
		
		# CDR
		stripchart(cdr_est_model ~ livelihood, data=subset(surveys, location1=="Somalia" & baseline_ipc=="yes" & eligible_mortality=="yes"),
				   vertical=TRUE, group.names=c("agro-pastoral", "IDP", "pastoralist", "riverine", "urban"), ylab="deaths per 10,000 person-days",
				   pch=1, col="red", main="crude death rate", cex.main=1)
		
		# U5DR
		stripchart(u5dr_est_model ~ livelihood, data=subset(surveys, location1=="Somalia" & baseline_ipc=="yes" & eligible_mortality=="yes"),
				   vertical=TRUE, group.names=c("agro-pastoral", "IDP", "pastoralist", "riverine", "urban"), ylab="deaths per 10,000 child-days",
				   pch=1, col="red", main="under 5 years death rate", cex.main=1)
				   
		# save plot
		savePlot("graph_baseline_method2.wmf",type="wmf") 			

		
		
				   
#.........................................................................................
### Plot trends in mortality and malnutrition across time

# create mortality graph for report
	# general parameters
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	par(mfrow=c(2,1), mar=c(1,4,2,1)+0.1, oma=c(4,1,1,1))

	# select eligible surveys
	mort <- subset(surveys, eligible_mortality=="yes")
	
	# calculate month in time series from Jan 2006 to Dec 2012 in which recall period was centered
	mort[, "t_mid"] <- (mort[, "y_survey"] - year[1]) * length(month) + mort[, "m_survey"] - floor(mort[, "recall_months"] / 2 )

	# plot CDR data by location
	plot( subset(mort, location1=="Somalia")[, "t_mid"] , subset(mort, location1=="Somalia")[, "cdr_est_model"], xaxt="n",
	      col="red", pch=1 , ylab="deaths per 10,000 person-days", xlab="", main = "crude death rate", cex.main=1, las=1)
	points( subset(mort, location1=="Somaliland")[, "t_mid"] , subset(mort, location1=="Somaliland")[, "cdr_est_model"] , col="blue", pch=4)
	points( subset(mort, location1=="Puntland")[, "t_mid"] , subset(mort, location1=="Puntland")[, "cdr_est_model"] , col="darkgreen", pch=2)
	abline(h=c(1,2,5), lty=3, col="grey")
	
	# add year ablines and legend
	abline(v=seq(min(mort$t_mid)+10, max(mort$t_mid), by=12), lty=3, col="grey")
	legend(x="topleft", legend=c("South-central Somalia", "Somaliland", "Puntland"), col=c("red", "blue", "darkgreen"), pch=c(1, 4, 2), pt.cex=c(1.1, 1.1, 1.1), bty="n" )

	# plot U5DR data by location
	plot( subset(mort, location1=="Somalia")[, "t_mid"] , subset(mort, location1=="Somalia")[, "u5dr_est_model"], xaxt="n", yaxp=c(0, 16, 8),
	      col="red", pch=1 , ylab="deaths per 10,000 child-days", xlab="", main = "under 5 years death rate", cex.main=1.1, las=1)
	points( subset(mort, location1=="Somaliland")[, "t_mid"] , subset(mort, location1=="Somaliland")[, "u5dr_est_model"] , col="blue", pch=4)
	points( subset(mort, location1=="Puntland")[, "t_mid"] , subset(mort, location1=="Puntland")[, "u5dr_est_model"] , col="darkgreen", pch=2)
	abline(h=c(2,4,10), lty=3, col="grey")

	# add year ablines
	abline(v=seq(min(mort$t_mid)+10, max(mort$t_mid), by=12), lty=3, col="grey")

	# add x axis and labels
	axis(1, at=seq(min(mort$t_mid)+1, max(mort$t_mid), by=3), col="black", labels=FALSE )

	lablist.m <- c("Apr", "Jul", "Oct", "Jan", "Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct",
				   "Jan", "Apr", "Jul")
	lablist.y <- c("2007", "2008", "2009", "2010", "2011", "2012")
	text(seq(min(mort$t_mid)+1, max(mort$t_mid), by=3),  par("usr")[3] - 0.8, labels = lablist.m, srt = 0, pos = 1, , xpd = NA, cex=1.1 )
	text(seq(min(mort$t_mid)+4, max(mort$t_mid), by=12),  par("usr")[3] - 2.5, labels = lablist.y, srt = 0, pos = 1, , xpd = NA, cex=1.1 )
	mtext("month-year", side=1, col="black", line=3, cex = 1.1)	
				   
	# save plot
	savePlot("graph_mortality_trends.wmf",type="wmf") 	


# create malnutrition graph for report
	# general parameters
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	par(mfrow=c(3,1), mar=c(1,4,2,1)+0.1, oma=c(4,1,1,1))

	# select eligible surveys
	nut  <- subset(surveys, eligible_anthropometry=="yes")
	
	# calculate month in time series from Jan 2006 to Dec 2012 in which urvey was done
	nut[, "t_survey"] <- (nut[, "y_survey"] - year[1]) * length(month) + nut[, "m_survey"]

	# plot GAM WHO data by location
	plot( subset(nut, location1=="Somalia")[, "t_survey"] , subset(nut, location1=="Somalia")[, "gam_whz_who"], xaxt="n", ylim=c(0,60),
	      col="red", pch=1 , ylab="prevalence (%)", xlab="", main = "prevalence of global acute malnutrition (weight-for-height + oedema)", cex.main=1, las=1)
	points( subset(nut, location1=="Somaliland")[, "t_survey"] , subset(nut, location1=="Somaliland")[, "gam_whz_who"] , col="blue", pch=4)
	points( subset(nut, location1=="Puntland")[, "t_survey"] , subset(nut, location1=="Puntland")[, "gam_whz_who"] , col="darkgreen", pch=2)
	abline(h=c(10,20,30), lty=3, col="grey")
	
	# add year ablines and legend
	abline(v=seq(min(nut$t_survey)+9, max(nut$t_survey), by=12), lty=3, col="grey")
	legend(x="topleft", legend=c("South-central Somalia", "Somaliland", "Puntland"), col=c("red", "blue", "darkgreen"), pch=c(1, 4, 2), pt.cex=c(1.1, 1.1, 1.1), bty="n" )

	# plot GAM by MUAC data by location
	plot( subset(nut, location1=="Somalia")[, "t_survey"] , subset(nut, location1=="Somalia")[, "gam_muac"], xaxt="n", ylim=c(0,60),
	      col="red", pch=1 , ylab="prevalence (%)", xlab="", main = "prevalence of global acute malnutrition (middle-upper arm circumference + oedema)", cex.main=1, las=1)
	points( subset(nut, location1=="Somaliland")[, "t_survey"] , subset(nut, location1=="Somaliland")[, "gam_muac"] , col="blue", pch=4)
	points( subset(nut, location1=="Puntland")[, "t_survey"] , subset(nut, location1=="Puntland")[, "gam_muac"] , col="darkgreen", pch=2)
	abline(h=c(10,20,30), lty=3, col="grey")
	
	# add year ablines
	abline(v=seq(min(nut$t_survey)+9, max(nut$t_survey), by=12), lty=3, col="grey")

	# plot the proportion of oedema among GAM cases by location
	plot( subset(nut, location1=="Somalia")[, "t_survey"] , subset(nut, location1=="Somalia")[, "oedema"]*100 / subset(nut, location1=="Somalia")[, "gam_whz_who"],
	      xaxt="n", ylim=c(0,20), col="red", pch=1 , ylab="proportion (%)", xlab="", main = "proportion of bilateral oedema among global acute malnutrition (weight-for-height + oedema) cases", cex.main=1, las=1)
	points( subset(nut, location1=="Somaliland")[, "t_survey"] , subset(nut, location1=="Somaliland")[, "oedema"]*100 / subset(nut, location1=="Somaliland")[, "gam_whz_who"] , col="blue", pch=4)
	points( subset(nut, location1=="Puntland")[, "t_survey"] , subset(nut, location1=="Puntland")[, "oedema"]*100  / subset(nut, location1=="Puntland")[, "gam_whz_who"] , col="darkgreen", pch=2)
	abline(h=c(5,10,15), lty=3, col="grey")

	# add year ablines
	abline(v=seq(min(nut$t_survey)+9, max(nut$t_survey), by=12), lty=3, col="grey")

	# add x axis and labels
	axis(1, at=seq(min(nut$t_survey), max(nut$t_survey), by=3), col="black", labels=FALSE )

	lablist.m <- c("Apr", "Jul", "Oct", "Jan", "Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct",
				   "Jan", "Apr", "Jul")
	lablist.y <- c("2007", "2008", "2009", "2010", "2011", "2012")
	text(seq(min(nut$t_survey), max(nut$t_survey), by=3),  par("usr")[3] - 0.3, labels = lablist.m, srt = 0, pos = 1, , xpd = NA, cex=1.1 )
	text(seq(min(nut$t_survey)+3, max(nut$t_survey), by=12),  par("usr")[3] - 2.2, labels = lablist.y, srt = 0, pos = 1, , xpd = NA, cex=1.1 )
	mtext("month-year", side=1, col="black", line=2.8, cex=0.9)	
				   
	# save plot
	savePlot("graph_malnutrition_trends.wmf",type="wmf") 	

# create table with surveys done in Somalia in July 2011-December 2011

mort2011 <- subset(mort, location1=="Somalia" & y_survey==2011 & m_survey > 6)[, c("survey_id", "y_survey", "m_survey", "cdr_est_model", "cdr_lci_model", "cdr_uci_model", 
                                                                                 "u5dr_est_model", "u5dr_lci_model", "u5dr_uci_model" )]

mort2011 <- mort2011[order(mort2011$m_survey), ]
mort2011[, "cdr"] <- paste(mort2011[, "cdr_est_model"], " (", mort2011[, "cdr_lci_model"], "-", mort2011[, "cdr_uci_model"], ")", sep="") 
mort2011[, "u5dr"] <- paste(mort2011[, "u5dr_est_model"], " (", mort2011[, "u5dr_lci_model"], "-", mort2011[, "u5dr_uci_model"], ")", sep="") 

write.csv(mort2011[, c("survey_id", "m_survey", "cdr", "u5dr")], "table_mortality_2011.csv")

#.........................................................................................
###Save dataset

# sort variables in desired order

surveys <- surveys[, c(
 "survey_id", "y_survey", "m_survey", "cluster", "location1", "location2", "region1", "region2", "region3", "region4",
 "stratum1", "stratum2", "stratum3", "stratum4",
 "stratum1_cov", "stratum2_cov", "stratum3_cov", "stratum4_cov", 
 "district_spec", "livelihood", "geo_other", "lzone1", "lzone2", "lzone3", "lzone4", "lzone5",
 "district1", "district2", "district3", "district4", "district5", "district6", "district7", "district8", "district9", "district10", "district11",
 "backup_district1", "backup_district2", "report", "dataset", "survey_design", "n_clusters",
 "bednet", "water", "sanitation", "food_groups", "illness", "health_seeking", "diarrhoea", "outbreak", "vc_measles", "vc_polio", "breastfeeding",
 "gam_whz_who", "sam_whz_who", "gam_whz_nchs", "sam_whz_nchs", "gam_muac", "sam_muac_110", "sam_muac_115", "oedema", "pregnant_gam_muac",
 "recall_months", "n_hh", "n_u5", "u5deaths", "n_people", "deaths", "deaths_lshtm", "deaths_u5_lshtm", "deaths_u1_lshtm", "prop_deaths_u5", "prop_deathsu5_u1",                 
 "cdr_est", "cdr_lci", "cdr_uci", "cdr_lshtm_est", "cdr_lshtm_lci", "cdr_lshtm_uci", "cdr_lshtm_deff", "discordance_cdr",
 "cdr_est_model", "cdr_lci_model", "cdr_uci_model", "ln_cdr_se", "cdr_ci_symmetry", "cdr_ci_correct", "cdr_sampling_weight1", "cdr_sampling_weight2",
 "u5dr_est", "u5dr_lci", "u5dr_uci", "u5dr_lshtm_est", "u5dr_lshtm_lci", "u5dr_lshtm_uci", "u5dr_lshtm_deff", "discordance_u5dr",
 "u5dr_est_model", "u5dr_lci_model", "u5dr_uci_model", "ln_u5dr_se", "u5dr_ci_symmetry", "u5dr_ci_correct", "u5dr_sampling_weight1", "u5dr_sampling_weight2", 
 "births", "cbr", "arrival_rate", "u5arrival_rate", "departure_rate", "u5departure_rate", "mean_hh_size", "mean_hh_size_u5", "prop_hh_u5",
 "m_mid", "y_mid", "quality_weight", "bias", "notes", "eligible_mortality", "eligible_anthropometry", 
 "rate_incidents_lag0", "rate_incidents_lag3",
 "wfp_present_lag0", "wfp_present_lag1", "wfp_present_lag2", "wfp_present_lag3", "wfp_present_lag4", "wfp_present_lag5", "wfp_present_lag6",
 "AToTw_lag0", "AToTg_lag0", "RToTw_lag0", "RToTg_lag0", "RToT_liv_lag0", "AToTw_lag1", "AToTg_lag1", "RToTw_lag1", "RToTg_lag1", "RToT_liv_lag1",
 "AToTw_lag2", "AToTg_lag2", "RToTw_lag2", "RToTg_lag2", "RToT_liv_lag2", "AToTw_lag3", "AToTg_lag3", "RToTw_lag3", "RToTg_lag3", "RToT_liv_lag3",
 "AToTw_lag4", "AToTg_lag4", "RToTw_lag4", "RToTg_lag4", "RToT_liv_lag4", "AToTw_lag5", "AToTg_lag5", "RToTw_lag5", "RToTg_lag5", "RToT_liv_lag5",
 "AToTw_lag6", "AToTg_lag6", "RToTw_lag6", "RToTg_lag6", "RToT_liv_lag6",
 "baseline_tot", "baseline_ipc", 
 "cdr_survey_weight1", "cdr_survey_weight2", "u5dr_survey_weight1", "u5dr_survey_weight2"
)]


# write to file
write.csv(surveys, "survey_metadata.csv" , row.names=FALSE)


