#............................................................................................
### ~~ R CODE FOR STATISTICAL MODELLING RELATED TO SOMALIA DEATH TOLL ESTIMATION (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (March 2013)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis") #office

# required packages
library(lattice)
library(nlme)
library(lme4)
library(lmmfit)
library(boot)
library(DAAG)
library(MASS)
library(TeachingDemos)
library(psych)
library(car)

# read data
year <- seq(2006, 2012, 1) #sequence of years
month <- seq(1, 12, 1) #sequence of months
surveys <- read.csv("survey_metadata.csv") # survey metadata


#.........................................................................................
### Predictive model for CDR extrapolation (see also conceptual framework in report)

# select data eligible for analysis
dat <- subset(surveys, eligible_mortality=="yes")

# convert independent variables to log metric
dat[, "ln.cdr"] <- log(dat[, "cdr_est_model"])
dat[, "ln.u5dr"] <- log(dat[, "u5dr_est_model"])

# explore government services
	# compare mortality distributions for the three locations
	densityplot(~ln.cdr | location1, data=dat, layout=c(1,3))
	densityplot(~ln.u5dr | location1, data=dat, layout=c(1,3))

	# convert into binary variable (Somalia vs Puntland/Somaliland)
	dat[, "m.location"] <- ifelse(dat[, "location1"] %in% c("Somaliland", "Puntland") , "Sland-Ptland", "Somalia")

	# explore association with mortality
	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.location"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.location"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.location"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.location"]), weights=dat[, "u5dr_survey_weight1"] ) )

# explore armed conflict
	# look at correlation between non-negative armed conflict rates and mortality - different lags
	plot(subset(dat, rate_incidents_lag0 > 0)[, "ln.cdr"], log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"]) )
	lines(lowess(subset(dat, rate_incidents_lag0 > 0)[, "ln.cdr"] , log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"])), col="blue")

	plot(subset(dat, rate_incidents_lag3 > 0)[, "ln.cdr"], log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"]) )
	lines(lowess(subset(dat, rate_incidents_lag3 > 0)[, "ln.cdr"] , log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"])), col="blue")

	plot(subset(dat, rate_incidents_lag0 > 0)[, "ln.u5dr"], log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"]) )
	lines(lowess(subset(dat, rate_incidents_lag0 > 0)[, "ln.u5dr"] , log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"])), col="blue")

	plot(subset(dat, rate_incidents_lag3 > 0)[, "ln.u5dr"], log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"]) )
	lines(lowess(subset(dat, rate_incidents_lag3 > 0)[, "ln.u5dr"] , log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"])), col="blue")

	plot(subset(dat, rate_incidents_lag0 > 0)[, "cdr_est_model"], log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"]) )
	lines(lowess(subset(dat, rate_incidents_lag0 > 0)[, "cdr_est_model"] , log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"])), col="blue")

	plot(subset(dat, rate_incidents_lag3 > 0)[, "cdr_est_model"], log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"]) )
	lines(lowess(subset(dat, rate_incidents_lag3 > 0)[, "cdr_est_model"] , log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"])), col="blue")

	plot(subset(dat, rate_incidents_lag0 > 0)[, "u5dr_est_model"], log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"]) )
	lines(lowess(subset(dat, rate_incidents_lag0 > 0)[, "u5dr_est_model"] , log(subset(dat, rate_incidents_lag0 > 0)[, "rate_incidents_lag0"])), col="blue")

	plot(subset(dat, rate_incidents_lag3 > 0)[, "u5dr_est_model"], log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"]) )
	lines(lowess(subset(dat, rate_incidents_lag3 > 0)[, "u5dr_est_model"] , log(subset(dat, rate_incidents_lag3 > 0)[, "rate_incidents_lag3"])), col="blue")

	
	# cut into categories of 0, 0-1, 1-2, 2 and above per 100000 person-days
	dat[, "m.rate_incidents_lag0_cat"] <- cut(dat[, "rate_incidents_lag0"], c(0, 0.000001, 1, 2, max(dat[, "rate_incidents_lag0"], na.rm=TRUE ) ) ,
											  include.lowest=TRUE, labels = c("0", "0-1", "1-2", "2+") )
	
	dat[, "m.rate_incidents_lag3_cat"] <- cut(dat[, "rate_incidents_lag3"], c(0, 0.000001, 1, 2, max(dat[, "rate_incidents_lag3"], na.rm=TRUE ) ) ,
											  include.lowest=TRUE, labels = c("0", "0-1", "1-2", "2+") )
	
	# cut into categories of 0 vs more than 0
	dat[, "m.rate_incidents_lag0_bin"] <- cut(dat[, "rate_incidents_lag0"], c(0, 0.000001, max(dat[, "rate_incidents_lag0"], na.rm=TRUE ) ) ,
											  include.lowest=TRUE, labels = c("no incidents", "any incidents") )

	dat[, "m.rate_incidents_lag3_bin"] <- cut(dat[, "rate_incidents_lag3"], c(0, 0.000001, max(dat[, "rate_incidents_lag3"], na.rm=TRUE ) ) ,
											  include.lowest=TRUE, labels = c("no incidents", "any incidents") )
	

	# explore association with mortality
	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.rate_incidents_lag0_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.rate_incidents_lag0_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag0_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag0_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.rate_incidents_lag3_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.rate_incidents_lag3_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag3_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag3_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.rate_incidents_lag0_bin"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.rate_incidents_lag0_bin"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag0_bin"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag0_bin"]), weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.rate_incidents_lag3_bin"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.rate_incidents_lag3_bin"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag3_bin"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.rate_incidents_lag3_bin"]), weights=dat[, "u5dr_survey_weight1"] ) )
		
	
# explore season (using month in the middle of the recall period as the basis)

	# calculate month in time series from Jan 2006 to Dec 2012 in which recall period was centered
	dat[, "t_mid"] <- (dat[, "y_survey"] - year[1]) * length(month) + dat[, "m_survey"] - floor(dat[, "recall_months"] / 2)

	# look at evidence of any seasonality
	plot( dat[, "t_mid"] , dat[, "ln.cdr"] )
	lines(lowess(dat[, "t_mid"], dat[, "ln.cdr"], f = 0.3), col="blue")

	plot( dat[, "t_mid"] , dat[, "ln.u5dr"] )
	lines(lowess(dat[, "t_mid"], dat[, "ln.u5dr"], f = 0.3), col="blue")

	plot( dat[, "t_mid"] , dat[, "cdr_est_model"] )
	lines(lowess(dat[, "t_mid"], dat[, "cdr_est_model"], f = 0.3), col="blue")

	plot( dat[, "t_mid"] , dat[, "u5dr_est_model"] )
	lines(lowess(dat[, "t_mid"], dat[, "u5dr_est_model"], f = 0.3), col="blue")
		
	
	# look at correlation between month and mortality
	plot( dat[, "m_mid"] , dat[, "ln.cdr"] )
	lines(lowess(dat[, "m_mid"], dat[, "ln.cdr"], f=0.3), col="blue")

	plot( dat[, "m_mid"] , dat[, "ln.u5dr"] )
	lines(lowess(dat[, "m_mid"], dat[, "ln.u5dr"], f=0.3), col="blue")

	plot( dat[, "m_mid"] , dat[, "cdr_est_model"] )
	lines(lowess(dat[, "m_mid"], dat[, "cdr_est_model"], f=0.3), col="blue")

	plot( dat[, "m_mid"] , dat[, "u5dr_est_model"] )
	lines(lowess(dat[, "m_mid"], dat[, "u5dr_est_model"], f=0.3), col="blue")

	
	# regroup months into main hunger seasons
	f.season <- function(f.dat) {

		if (as.numeric(f.dat[["m_mid"]]) %in% c(2, 3, 4) )   return("Feb-Mar-Apr (hunger)")
		if (as.numeric(f.dat[["m_mid"]]) %in% c(5, 6, 7)  )  return("May-Jun-Jul (post-hunger)")
		if (as.numeric(f.dat[["m_mid"]]) %in% c(8, 9, 10) )  return("Aug-Sep-Oct (lean)")
		if (as.numeric(f.dat[["m_mid"]]) %in% c(11, 12, 1) ) return("Nov-Dec-Jan (post-lean)")
			
	}

	dat[, "m.m_mid_cat"] <- apply(dat, 1, f.season)
	
	# explore association with mortality (including before 2011 peak - perhaps easier to visualise any seasonality before then)
	summary( lm( dat[, "ln.cdr"] ~ dat[, "m.m_mid_cat"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "m.m_mid_cat"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "m.m_mid_cat"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "m.m_mid_cat"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( subset(dat, y_survey < 2011)[, "ln.cdr"] ~ subset(dat, y_survey < 2011)[, "m.m_mid_cat"], weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "ln.u5dr"] ~ subset(dat, y_survey < 2011)[, "m.m_mid_cat"], weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "cdr_est_model"] ~ subset(dat, y_survey < 2011)[, "m.m_mid_cat"], weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "u5dr_est_model"] ~ subset(dat, y_survey < 2011)[, "m.m_mid_cat"], weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )
	

# explore food assistance (WFP presence)
	
	# explore association with mortality (different lags)
	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag0"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag0"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag0"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag0"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag1"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag1"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag1"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag1"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag2"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag2"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag2"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag2"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag3"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag3"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag3"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag3"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag4"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag4"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag4"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag4"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag5"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag5"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag5"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag5"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "wfp_present_lag6"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "wfp_present_lag6"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "wfp_present_lag6"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "wfp_present_lag6"], weights=dat[, "u5dr_survey_weight1"] ) )
	

# Explore livelihood

	# compare mortality distribution for the five livelihoods
	densityplot(~ln.cdr | livelihood,  data=dat, layout=c(1,5))
	densityplot(~ln.u5dr | livelihood, data=dat, layout=c(1,5))
	densityplot(~cdr_est_model | livelihood,  data=dat, layout=c(1,5))
	densityplot(~u5dr_est_model | livelihood, data=dat, layout=c(1,5))

	# explore association with mortality
	summary( lm( dat[, "ln.cdr"] ~ dat[, "livelihood"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "livelihood"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "livelihood"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "livelihood"], weights=dat[, "u5dr_survey_weight1"] ) )

	
# Explore other secular trends (i.e. year)

	# explore association with mortality before 2011 (as continuous variable)
	summary( lm( subset(dat, y_survey < 2011)[, "ln.cdr"] ~ subset(dat, y_survey < 2011)[, "y_mid"], weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "ln.u5dr"] ~ subset(dat, y_survey < 2011)[, "y_mid"], weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "cdr_est_model"] ~ subset(dat, y_survey < 2011)[, "y_mid"], weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "u5dr_est_model"] ~ subset(dat, y_survey < 2011)[, "y_mid"], weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )

	# explore association with mortality before 2011 (as factor)
	summary( lm( subset(dat, y_survey < 2011)[, "ln.cdr"] ~ as.factor(subset(dat, y_survey < 2011)[, "y_mid"]), weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "ln.u5dr"] ~ as.factor(subset(dat, y_survey < 2011)[, "y_mid"]), weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "cdr_est_model"] ~ as.factor(subset(dat, y_survey < 2011)[, "y_mid"]), weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "u5dr_est_model"] ~ as.factor(subset(dat, y_survey < 2011)[, "y_mid"]), weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )	


# Explore increased disease transmission (epidemics)

	# explore data
	table(dat[, "outbreak"])
	
	# generate binary variable (epidemic yes or no), categorical (0 epidemics, 1, 2+), binary (cholera/AWD yes-no, measles yes-no)
	dat[, "m.outbreak_bin"] <- ifelse(dat[, "outbreak"] == "none", "no outbreak", "1+ outbreaks")

	f.outbreak <- function(f.dat) {
	
		if (f.dat[["outbreak"]] == "none") return ("no outbreaks")
		if (f.dat[["outbreak"]] != "none" & grepl(",", f.dat[["outbreak"]]) == FALSE ) return ("1 outbreak")
		if (f.dat[["outbreak"]] != "none" & grepl(",", f.dat[["outbreak"]]) == TRUE ) return ("2+ outbreaks")
	
	}
	dat[, "m.outbreak_cat"] <- apply(dat, 1, f.outbreak)

	dat[, "m.outbreak_cholera"] <- ifelse(grepl("cholera", dat[, "outbreak"]) == TRUE | grepl("AWD", dat[, "outbreak"]) == TRUE,
	                                      "cholera/AWD outbreak", "no cholera/AWD outbreak")
	
	dat[, "m.outbreak_measles"] <- ifelse(grepl("measles", dat[, "outbreak"]) == TRUE, "measles outbreak", "no measles outbreak")
	
	# compare mortality distributions with and without outbreaks
	densityplot(~ln.cdr | m.outbreak_bin,  data=dat, layout=c(1,2))
	densityplot(~ln.u5dr | m.outbreak_bin, data=dat, layout=c(1,2))
	densityplot(~cdr_est_model | m.outbreak_bin,  data=dat, layout=c(1,2))
	densityplot(~u5dr_est_model | m.outbreak_bin, data=dat, layout=c(1,2))

	densityplot(~ln.cdr | m.outbreak_cat,  data=dat, layout=c(1,3))
	densityplot(~ln.u5dr | m.outbreak_cat, data=dat, layout=c(1,3))
	densityplot(~cdr_est_model | m.outbreak_cat,  data=dat, layout=c(1,3))
	densityplot(~u5dr_est_model | m.outbreak_cat, data=dat, layout=c(1,3))

	densityplot(~ln.cdr | m.outbreak_cholera,  data=dat, layout=c(1,2))
	densityplot(~ln.u5dr | m.outbreak_cholera, data=dat, layout=c(1,2))
	densityplot(~cdr_est_model | m.outbreak_cholera,  data=dat, layout=c(1,2))
	densityplot(~u5dr_est_model | m.outbreak_cholera, data=dat, layout=c(1,2))

	densityplot(~ln.cdr | m.outbreak_measles,  data=dat, layout=c(1,2))
	densityplot(~ln.u5dr | m.outbreak_measles, data=dat, layout=c(1,2))
	densityplot(~cdr_est_model | m.outbreak_measles,  data=dat, layout=c(1,2))
	densityplot(~u5dr_est_model | m.outbreak_measles, data=dat, layout=c(1,2))

	# explore associations with mortality
	summary( lm( dat[, "ln.cdr"] ~ dat[, "m.outbreak_bin"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "m.outbreak_bin"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "m.outbreak_bin"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "m.outbreak_bin"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ as.factor(dat[, "m.outbreak_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ as.factor(dat[, "m.outbreak_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ as.factor(dat[, "m.outbreak_cat"]), weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ as.factor(dat[, "m.outbreak_cat"]), weights=dat[, "u5dr_survey_weight1"] ) )
	
	summary( lm( dat[, "ln.cdr"] ~ dat[, "m.outbreak_cholera"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "m.outbreak_cholera"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "m.outbreak_cholera"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "m.outbreak_cholera"], weights=dat[, "u5dr_survey_weight1"] ) )

	summary( lm( dat[, "ln.cdr"] ~ dat[, "m.outbreak_bin"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "ln.u5dr"] ~ dat[, "m.outbreak_bin"], weights=dat[, "u5dr_survey_weight1"] ) )
	summary( lm( dat[, "cdr_est_model"] ~ dat[, "m.outbreak_bin"], weights=dat[, "cdr_survey_weight1"] ) )
	summary( lm( dat[, "u5dr_est_model"] ~ dat[, "m.outbreak_bin"], weights=dat[, "u5dr_survey_weight1"] ) )

	# explore associations with mortality before 2011
	summary( lm( subset(dat, y_survey < 2011)[, "ln.cdr"] ~ as.factor(subset(dat, y_survey < 2011)[, "m.outbreak_cat"]), weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "ln.u5dr"] ~ as.factor(subset(dat, y_survey < 2011)[, "m.outbreak_cat"]), weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "cdr_est_model"] ~ as.factor(subset(dat, y_survey < 2011)[, "m.outbreak_cat"]), weights=subset(dat, y_survey < 2011)[, "cdr_survey_weight1"] ) )
	summary( lm( subset(dat, y_survey < 2011)[, "u5dr_est_model"] ~ as.factor(subset(dat, y_survey < 2011)[, "m.outbreak_cat"]), weights=subset(dat, y_survey < 2011)[, "u5dr_survey_weight1"] ) )


# Explore ability to purchase food (ToT)

	# look at correlation between RToT and mortality
		
		# lag 0
			# log RToT_liv
			plot( log(dat[, "RToT_liv_lag0"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag0"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag0"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag0"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag0"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag0"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag0"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag0"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# RToT_liv (untransformed)	
			plot( dat[, "RToT_liv_lag3"] , dat[, "ln.cdr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "ln.u5dr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "cdr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "u5dr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		

		# lag 3
			# log RToT_liv
			plot( log(dat[, "RToT_liv_lag3"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag3"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag3"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag3"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag3"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag3"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag3"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag3"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# RToT_liv (untransformed)	
			plot( dat[, "RToT_liv_lag3"] , dat[, "ln.cdr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "ln.u5dr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "cdr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag3"] , dat[, "u5dr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag3"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		
		
		# lag 6
			# log RToT_liv
			plot( log(dat[, "RToT_liv_lag6"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag6"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag6"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag6"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag6"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag6"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "RToT_liv_lag6"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "RToT_liv_lag6"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# RToT_liv (untransformed)	
			plot( dat[, "RToT_liv_lag6"] , dat[, "ln.cdr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag6"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag6"] , dat[, "ln.u5dr"] )
			lines(smooth.spline(dat[, "RToT_liv_lag6"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag6"] , dat[, "cdr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag6"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "RToT_liv_lag6"] , dat[, "u5dr_est_model"] )
			lines(smooth.spline(dat[, "RToT_liv_lag6"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		
	
	# create categorical variable to account for threshold effect and explore association with mortality, for any lag
	for (i in c(0:6) ) {

	# for each lag...
		dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")] <- cut( dat[, paste("RToT_liv_lag", i, sep="")] ,
		                                                         c(0, 0.5, 0.75, 1, max(dat[, paste("RToT_liv_lag", i, sep="")], na.rm=TRUE) ), 
											                     include.lowest=TRUE, labels = c("0.00-0.49", "0.50-0.74", "0.75-0.99", "1+") )
		print ( table(dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")]) )
		
		}	

	
	# explore association of AToT with mortality
		# for each lag...
		for (i in c(0:6) ) {
		
			print (paste ("*************FOR LAG = ", i, sep="") )
			
			# RToT_liv (log, continuous)
			print( summary( lm( dat[, "ln.cdr"] ~ log(dat[, paste("RToT_liv_lag", i, sep="")]), weights=dat[, "cdr_survey_weight1"] ) ) ) 
			print( summary( lm( dat[, "ln.u5dr"] ~ log(dat[, paste("RToT_liv_lag", i, sep="")]), weights=dat[, "u5dr_survey_weight1"] ) ) ) 
			print( summary( lm( dat[, "cdr_est_model"] ~ log(dat[, paste("RToT_liv_lag", i, sep="")]), weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "u5dr_est_model"] ~ log(dat[, paste("RToT_liv_lag", i, sep="")]), weights=dat[, "u5dr_survey_weight1"] ) ) )			
			
			# RToT_liv (untransformed, continuous)	
			print( summary( lm( dat[, "ln.cdr"] ~ dat[, paste("RToT_liv_lag", i, sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "ln.u5dr"] ~ dat[, paste("RToT_liv_lag", i, sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "cdr_est_model"] ~ dat[, paste("RToT_liv_lag", i, sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "u5dr_est_model"] ~ dat[, paste("RToT_liv_lag", i, sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )
		
			# RToT_liv (categorical)
			print( summary( lm( dat[, "ln.cdr"] ~ dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "ln.u5dr"] ~ dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )

		
		}	

	
	# look at correlation between AToT and mortality
		
		# lag 0
			# log AToTw
			plot( log(dat[, "AToTw_lag0"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag0"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag0"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag0"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag0"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag0"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag0"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag0"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# AToTw (untransformed)	
			plot( dat[, "AToTw_lag3"] , dat[, "ln.cdr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "ln.u5dr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "cdr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "u5dr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		

		# lag 3
			# log AToTw
			plot( log(dat[, "AToTw_lag3"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag3"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag3"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag3"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag3"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag3"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag3"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag3"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# AToTw (untransformed)	
			plot( dat[, "AToTw_lag3"] , dat[, "ln.cdr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "ln.u5dr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "cdr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag3"] , dat[, "u5dr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag3"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		
		
		# lag 6
			# log AToTw
			plot( log(dat[, "AToTw_lag6"]) , dat[, "ln.cdr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag6"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag6"]) , dat[, "ln.u5dr"] )
			lines(smooth.spline(log(dat[, "AToTw_lag6"]), y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag6"]) , dat[, "cdr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag6"]), y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( log(dat[, "AToTw_lag6"]) , dat[, "u5dr_est_model"] )
			lines(smooth.spline(log(dat[, "AToTw_lag6"]), y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			# AToTw (untransformed)	
			plot( dat[, "AToTw_lag6"] , dat[, "ln.cdr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag6"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag6"] , dat[, "ln.u5dr"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag6"], y = dat[, "ln.u5dr"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag6"] , dat[, "cdr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag6"], y = dat[, "cdr_est_model"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)
			
			plot( dat[, "AToTw_lag6"] , dat[, "u5dr_est_model"], xlim=c(0,35000) )
			lines(smooth.spline(dat[, "AToTw_lag6"], y = dat[, "u5dr_est_model"], w = dat[, "u5dr_survey_weight1"], spar = 1), col="blue" )
			Sys.sleep(1)		


	# create graph for report
		# general parameters
		windowsFonts(Calibri=windowsFont("Calibri"))
		par(family="Calibri")
		par(mfrow=c(4,1), mar=c(1,4,2,1), oma=c(5,1,1,1))
		
		# lag 0
		plot( dat[, "AToTw_lag0"] , dat[, "cdr_est_model"], xaxt="n", xlim=c(5000,30000), ylim=c(0,17), col="blue", pch=2 , main="lag = 0 months",
		      ylab="", xlab="", cex.main=1.1)
		points( dat[, "AToTw_lag0"] , dat[, "u5dr_est_model"] , col="red")
		abline(v=seq(5000, 30000, by=5000), lty=3, col="grey")
		legend(x="topright", legend=c("crude death rate", "under 5 years death rate"),
			   col=c("blue", "red"), pch=c(2, 1), pt.cex=c(1, 1), bty="n" )
		
		# lag 2
		plot( dat[, "AToTw_lag2"] , dat[, "cdr_est_model"], xaxt="n", xlim=c(5000,30000), ylim=c(0,17), col="blue", pch=2 , main="lag = 2 months",
		      ylab="", xlab="", cex.main=1.1 )
		points( dat[, "AToTw_lag2"] , dat[, "u5dr_est_model"] , col="red")
		abline(v=seq(5000, 30000, by=5000), lty=3, col="grey")

		# lag 4		
		plot( dat[, "AToTw_lag4"] , dat[, "cdr_est_model"], xaxt="n", xlim=c(5000,30000), ylim=c(0,17), col="blue", pch=2 , main="lag = 4 months",
		      ylab="", xlab="", cex.main=1.1 )
		points( dat[, "AToTw_lag4"] , dat[, "u5dr_est_model"] , col="red")
		abline(v=seq(5000, 30000, by=5000), lty=3, col="grey")

		# lag 6		
		plot( dat[, "AToTw_lag6"] , dat[, "cdr_est_model"], xaxt="n", xlim=c(5000,30000), ylim=c(0,17), col="blue", pch=2 , main="lag = 6 months",
		      ylab="", xlab="", cex.main=1.1  )
		points( dat[, "AToTw_lag6"] , dat[, "u5dr_est_model"] , col="red")
		abline(v=seq(5000, 30000, by=5000), lty=3, col="grey")
		
		# add x axis and label
		par(new=T)
		axis(1, col="black")
		mtext(1, text="absolute terms of trade (Kcal cereal per daily wage, trimester mean)", line=3, , cex=0.75)		
		
		# add y label
		mtext("deaths per 10,000 person-days", side=2, line = -1, outer=TRUE, cex=0.75)				
					   
		# save plot
		savePlot("graph_AToTw_mortality.wmf",type="wmf") 	

		
	
	# create categorical variable to account for threshold effect and explore association with mortality, for any lag
	for (i in c(0:6) ) {

	# for each lag...
		dat[, paste("m.AToTw_lag", i, "_cat", sep="")] <- cut( dat[, paste("AToTw_lag", i, sep="")] ,
		                                                         c(0, 10000, 15000, 20000, 25000, max(dat[, paste("AToTw_lag", i, sep="")], na.rm=TRUE) ), 
											                     include.lowest=TRUE, labels = c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+") )
		print ( table(dat[, paste("m.AToTw_lag", i, "_cat", sep="")]) )
		
		}	

	
	# explore association of AToT with mortality
		# for each lag...
		for (i in c(0:6) ) {
		
			print (paste ("*************FOR LAG = ", i, sep="") )
			
			# AToTw (log, continuous)
			print( summary( lm( dat[, "ln.cdr"] ~ log(dat[, paste("AToTw_lag", i, sep="")]), weights=dat[, "cdr_survey_weight1"] ) ) ) 
			print( summary( lm( dat[, "ln.u5dr"] ~ log(dat[, paste("AToTw_lag", i, sep="")]), weights=dat[, "u5dr_survey_weight1"] ) ) ) 
			print( summary( lm( dat[, "cdr_est_model"] ~ log(dat[, paste("AToTw_lag", i, sep="")]), weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "u5dr_est_model"] ~ log(dat[, paste("AToTw_lag", i, sep="")]), weights=dat[, "u5dr_survey_weight1"] ) ) )			
			
			# AToTw (untransformed, continuous)	
			print( summary( lm( dat[, "ln.cdr"] ~ dat[, paste("AToTw_lag", i, sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "ln.u5dr"] ~ dat[, paste("AToTw_lag", i, sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "cdr_est_model"] ~ dat[, paste("AToTw_lag", i, sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "u5dr_est_model"] ~ dat[, paste("AToTw_lag", i, sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )
		
			# AToTw (categorical)
			print( summary( lm( dat[, "ln.cdr"] ~ dat[, paste("m.AToTw_lag", i, "_cat", sep="")], weights=dat[, "cdr_survey_weight1"] ) ) )
			print( summary( lm( dat[, "ln.u5dr"] ~ dat[, paste("m.AToTw_lag", i, "_cat", sep="")], weights=dat[, "u5dr_survey_weight1"] ) ) )

		
		}	

									 							 
		# Explore correlation between AToTw and different nutritional indicators

		# general parameters
			windowsFonts(Calibri=windowsFont("Calibri"))
			par(family="Calibri")
			par(mfrow=c(2,1), mar=c(2,4,1,1)+0.1, oma=c(1,1,1,1))
			
			# proportion of households consuming 4+ food types
			stripchart(food_groups ~ m.AToTw_lag2_cat, data=surveys,
					   vertical=TRUE, group.names=c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+"), ylab="percent consuming 4+ food types",
					   pch=1, col="blue", cex.main=1)
			
			# proportion of children 1y that are still breastfed
			stripchart(breastfeeding ~ m.AToTw_lag2_cat, data=surveys,
					   vertical=TRUE, group.names=c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+"), ylab="percent of children still breastfed",
					   pch=1, col="blue", cex.main=1)
			
			# GAM prevalence (weight for height)
			stripchart(gam_whz_who ~ m.AToTw_lag2_cat, data=surveys,
					   vertical=TRUE, group.names=c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+"), ylab="prevalence of GAM",
					   pch=1, col="blue", cex.main=1)
			
			# SAM prevalence (weight for height)
			stripchart(sam_whz_who ~ m.AToTw_lag2_cat, data=surveys,
					   vertical=TRUE, group.names=c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+"), ylab="prevalence of SAM",
					   pch=1, col="blue", cex.main=1)
			
		
		
# Set correct reference levels for some variables to be used in model building
dat <- within(dat, m.outbreak_cat <- relevel(as.factor(m.outbreak_cat), ref = "no outbreaks"))

for (i in c(0:6) ) {
			
	dat[, paste("m.AToTw_lag", i, "_cat", sep="")] <- factor(dat[, paste("m.AToTw_lag", i, "_cat", sep="")] ,
	                                                         levels = c("25,000+", "20,000-24,999", "15,000-19,999", "10,000-14,999", "0-9999") ) 
	
	dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")] <- factor(dat[, paste("m.RToT_liv_lag", i, "_cat", sep="")] ,
	                                                         levels = c("1+", "0.75-0.99", "0.50-0.74", "0.00-0.49") ) 
	}	

	for (i in c(0:6) ) {
			
	dat[, paste("wfp_present_lag", i, sep="")] <- factor(dat[, paste("wfp_present_lag", i, sep="")] ,
	                                                         levels = c("yes", "no") ) 
	
	}	


# Fit model for CDR extrapolation

	# Add all fixed effects
	fit1 <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
	           as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
			   data = dat, weights = cdr_survey_weight1
			   )
	summary(fit1)
	plot(residuals(fit1), fitted(fit1))
	histogram(residuals(fit1))
	qqnorm(	residuals(fit1)/sd(residuals(fit1)), xlim=c(-4,4), ylim=c(-4,4) )
	qqline( residuals(fit1)/sd(residuals(fit1)) )
	plot(dat[, as.character(formula(fit1)[2])] , fitted(fit1) )
	
		# possible tweaks in fixed effects
			#year as categorical
			fit1b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
						as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
						data = dat, weights = cdr_survey_weight1
						)	
			summary(fit1b)
			plot(residuals(fit1b), fitted(fit1b))
			histogram(residuals(fit1b))
			qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1b)/sd(residuals(fit1b)) )
			plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )
	
			#add season
			fit1b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
						as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.m_mid_cat),
						data = dat, weights = cdr_survey_weight1
						)	
			summary(fit1b)
			plot(residuals(fit1b), fitted(fit1b))
			histogram(residuals(fit1b))
			qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1b)/sd(residuals(fit1b)) )
			plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )

			#replace AToT with RToT
			fit1b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
						as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.RToT_liv_lag2_cat),
						data = dat, weights = cdr_survey_weight1
						)	
			summary(fit1b)
			plot(residuals(fit1b), fitted(fit1b))
			histogram(residuals(fit1b))
			qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1b)/sd(residuals(fit1b)) )
			plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )

			#add other lag effects for AToT and WFP presence
			fit1b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 + wfp_present_lag5 +
						as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.AToTw_lag5_cat),
						data = dat, weights = cdr_survey_weight1
						)	
			summary(fit1b)
			plot(residuals(fit1b), fitted(fit1b))
			histogram(residuals(fit1b))
			qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1b)/sd(residuals(fit1b)) )
			plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )
			
	# Add possible effect modifications (see report conceptual framework)
		# WFP presence x AToT
		fit2 <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
				   as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2)
		plot(residuals(fit2), fitted(fit2))
		histogram(residuals(fit2))
		qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2)/sd(residuals(fit2)) )		
		plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

		# WFP presence x AToT + season x AToT		
		fit2 <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
				   as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
				   + m.m_mid_cat * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2)
		plot(residuals(fit2), fitted(fit2))
		histogram(residuals(fit2))
		qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2)/sd(residuals(fit2)) )		
		plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

		# WFP presence x AToT + livelihood x AToT				
		fit2 <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
				   y_mid + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
				   + as.factor(livelihood) * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2)
		plot(residuals(fit2), fitted(fit2))
		histogram(residuals(fit2))
		qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2)/sd(residuals(fit2)) )		
		plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
		
		# WFP presence x AToT + epidemics x location				
		fit2 <- lm(ln.cdr ~ as.factor(m.rate_incidents_lag3_cat) + 
				   y_mid + as.factor(m.location) * as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
				   + as.factor(livelihood) * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2)
		plot(residuals(fit2), fitted(fit2))
		histogram(residuals(fit2))
		qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2)/sd(residuals(fit2)) )		
		plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
		
		# WFP presence x AToT + conflict incidents x epidemics				
		fit2 <- lm(ln.cdr ~ y_mid + as.factor(m.location) + 
				   as.factor(m.rate_incidents_lag3_cat) * as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
				   + as.factor(livelihood) * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2)
		plot(residuals(fit2), fitted(fit2))
		histogram(residuals(fit2))
		qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2)/sd(residuals(fit2)) )		
		plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
		
	# fixed effects model so far
	fit2 <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
			   as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
			   data = dat, weights = cdr_survey_weight1
			   )
	summary(fit2)
	plot(residuals(fit2), fitted(fit2))
	histogram(residuals(fit2))
	qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
	qqline( residuals(fit2)/sd(residuals(fit2)) )		
	plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
	sum(residuals(fit2)^2)/nrow(dat) # mean residual squares
	
		# is it overfitted? is the predictive power optimistic? do cross-validation to check
			# calculate press
			press(fit2)
			# compared to sum of squares of model
			sum(residuals(fit2)^2)
			
	# though optimism bias (overfitting) seems limited, try to reduce model		
		# take out livelihood?
		fit2b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
				   y_mid + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2b)
		plot(residuals(fit2b), fitted(fit2b))
		histogram(residuals(fit2b))
		qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
		plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
		sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
		press(fit2b)
		sum(residuals(fit2b)^2)
		anova (fit2b, fit2)
		
		# no, but take out year?
		fit2b <- lm(ln.cdr ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
				   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2b)
		plot(residuals(fit2b), fitted(fit2b))
		histogram(residuals(fit2b))
		qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
		plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
		sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
		press(fit2b)
		sum(residuals(fit2b)^2)
		anova (fit2b, fit2)
		
		# yes - also take out conflict incidents?
				fit2c <- lm(ln.cdr ~ as.factor(m.location) + as.factor(livelihood)  +
				   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
				   data = dat, weights = cdr_survey_weight1
				   )
		summary(fit2c)
		plot(residuals(fit2c), fitted(fit2c))
		histogram(residuals(fit2c))
		qqnorm(	residuals(fit2c)/sd(residuals(fit2c)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit2c)/sd(residuals(fit2c)) )		
		plot(dat[, as.character(formula(fit2c)[2])] , fitted(fit2c) )
		sum(residuals(fit2c)^2)/nrow(dat) # mean residual squares
		press(fit2c)
		sum(residuals(fit2c)^2)
		anova (fit2c, fit2)
		
		# no
		
	# model residuals continue to be non-normal, so try a Box-Cox transformation of the dependent variable, based on full model
		# fit best model so far but with untransformed dependent
		fit2b.un <- lm(cdr_est_model ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = cdr_survey_weight1
					   )	
		
		# find ML lambda parameter for Box-Cox transformation of dependent
		bc  <- boxcox(fit2b.un, data = dat, plotit=FALSE)	
		cdr.lambda <- bc$x[which.max(bc$y)] # gives lambda (=0.4)

		# function to transform dependent variable into Box-Cox metric (with scaling to allow for varying variance of residuals)
		f.bct <- function (f.y, f.lambda) {
			gm <- exp(mean(log(f.y))) # geometric mean of dependent variable
			
			return( (f.y^f.lambda - 1)/(f.lambda * gm^(f.lambda-1)) )

			}
		
		# generate CDR Box-Cox transformed
		dat[, "cdr.bct"] <- f.bct(dat[, "cdr_est_model"] , cdr.lambda) 	
		
		# function to back-transform fitted values from Box-Cox metric (useful for later prediction and model comparison)
		f.bctback <- function(f.tr, f.untr, f.lambda) {
			gm <- exp(mean(log(f.untr))) # geometric mean of dependent variable
			
			return ( (f.tr * (f.lambda * gm^(f.lambda - 1) ) + 1 )^(1/f.lambda) )

			}

		#rebuild model as above
			# Add all fixed effects
			fit1 <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
					   as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = cdr_survey_weight1
					   )
			summary(fit1)
			plot(residuals(fit1), fitted(fit1))
			histogram(residuals(fit1))
			qqnorm(	residuals(fit1)/sd(residuals(fit1)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1)/sd(residuals(fit1)) )
			plot(dat[, as.character(formula(fit1)[2])] , fitted(fit1) )
			
				# possible tweaks in fixed effects
					#year as categorical?
					fit1b <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
								data = dat, weights = cdr_survey_weight1
								)	
					summary(fit1b)
					plot(residuals(fit1b), fitted(fit1b))
					histogram(residuals(fit1b))
					qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1b)/sd(residuals(fit1b)) )
					plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )
			
					#yes - also add season?
					fit1c <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.m_mid_cat),
								data = dat, weights = cdr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )

					#no - replace AToT with RToT?
					fit1c <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.RToT_liv_lag2_cat),
								data = dat, weights = cdr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )

					#not for now but maybe later (residuals become normal - suggests AToT may need be transformed too) 
					# also add other lag effects for AToT and WFP presence?
					fit1c <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 + wfp_present_lag5 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.AToTw_lag5_cat),
								data = dat, weights = cdr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )
					
					# no
					
			# Add possible effect modifications (see report conceptual framework)
				# WFP presence x AToT
				fit2 <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# WFP presence x AToT + season x AToT		
				fit2 <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
						   + m.m_mid_cat * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# R2 improves somewhat but model becomes complex, QQ plot less normal, so no
				# WFP presence x AToT + livelihood x AToT				
				fit2 <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood) * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
				
				# same as above
				# WFP presence x AToT + epidemics x location				
				fit2 <- lm(cdr.bct ~ as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.location) * as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# same as above
				# WFP presence x AToT + conflict incidents x epidemics				
				fit2 <- lm(cdr.bct ~ as.factor(y_mid) + as.factor(m.location) + 
						   as.factor(m.rate_incidents_lag3_cat) * as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
				
				# same as above
				
			# fixed effects model so far
			fit2 <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
					   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = cdr_survey_weight1
					   )
			summary(fit2)
			plot(residuals(fit2), fitted(fit2))
			histogram(residuals(fit2))
			qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2)/sd(residuals(fit2)) )		
			plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
			sum(residuals(fit2)^2)/nrow(dat) # mean residual squares
			
				# is it overfitted? is the predictive power optimistic? do cross-validation to check
					# calculate press
					press(fit2)
					# compared to sum of squares of model
					sum(residuals(fit2)^2)
					
			# some optimism bias (possible overfitting), so try to reduce model		
				# take out livelihood?
				fit2b <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2b)
				plot(residuals(fit2b), fitted(fit2b))
				histogram(residuals(fit2b))
				qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
				plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
				sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
				press(fit2b)
				sum(residuals(fit2b)^2)
				anova (fit2b, fit2)
				
				# no (R2 stays the same but QQ plot becomes less normal), but take out year?
				fit2b <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2b)
				plot(residuals(fit2b), fitted(fit2b))
				histogram(residuals(fit2b))
				qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
				plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
				sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
				press(fit2b)
				sum(residuals(fit2b)^2)
				anova (fit2b, fit2)
				
				# yes - also take out conflict incidents?
				fit2c <- lm(cdr.bct ~ as.factor(m.location) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
				summary(fit2c)
				plot(residuals(fit2c), fitted(fit2c))
				histogram(residuals(fit2c))
				qqnorm(	residuals(fit2c)/sd(residuals(fit2c)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2c)/sd(residuals(fit2c)) )		
				plot(dat[, as.character(formula(fit2c)[2])] , fitted(fit2c) )
				sum(residuals(fit2c)^2)/nrow(dat) # mean residual squares
				press(fit2c)
				sum(residuals(fit2c)^2)
				anova (fit2c, fit2b)
				
				# no

			# try to make AToT more normal / have a more linear effect on response
				densityplot(dat[, "AToTw_lag2"])

				plot( dat[, "AToTw_lag2"] , dat[, "cdr.bct"], xlim=c(0,35000) )
				lines(smooth.spline(dat[, "AToTw_lag2"], y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
				Sys.sleep(1)

				plot( log(dat[, "AToTw_lag2"]) , dat[, "cdr.bct"] )
				lines(smooth.spline(log(dat[, "AToTw_lag2"]), y = dat[, "ln.cdr"], w = dat[, "cdr_survey_weight1"], spar = 1), col="blue" )
				Sys.sleep(1)
			
				# try various Box-Cox transformations of AToTw 
				for (i in seq(-1.0, 1.0, by = 0.1) ) {	
					
					# fit model with transformation given by lambda = i
					print(paste("NOW LOOKING AT LAMBA = ", i, sep=""))
					fit2b <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
							   as.factor(m.outbreak_cat) + wfp_present_lag2 * f.bct(dat[, "AToTw_lag2"], i),
							   data = dat, weights = cdr_survey_weight1
							   )
					print(summary(fit2b))
					plot(residuals(fit2b), fitted(fit2b))
					Sys.sleep(5)
					histogram(residuals(fit2b))
					Sys.sleep(5)
					qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
					Sys.sleep(5)
					plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
					sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
					press(fit2b)
					sum(residuals(fit2b)^2)
					Sys.sleep(5)
				}

				# no improvement seems possible; RToT_liv improves on normality of residuals but at too hich a cost (-10%) in R2

			# so this is the fixed effects model:
			fit2b <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = cdr_survey_weight1
					   )
			summary(fit2b)
			plot(residuals(fit2b), fitted(fit2b))
			histogram(residuals(fit2b))
			qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
			plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
			sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares (MSE)
			press(fit2b) # predicted MSE if model were applied to other data for prediction
			sum(residuals(fit2b)^2)


	# Add cluster as random effect?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (1| cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# yes - fit improved (graphically) and residuals become more normal
		
	# Try other random effects grouped by cluster:
		# AToT?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
				
		# yes - further improvement in fit, residuals still normal
		
		# location?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster) + (m.location | cluster)", sep=""))
		fit3b <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3b)
		res <- dat[, as.character(terms(fit3b)[[2]])] - fitted(fit3b) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3b))
		histogram(res)		
		qqnorm(	residuals(fit3b)/sd(residuals(fit3b)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3b)/sd(residuals(fit3b)) )		
		plot(dat[, as.character(terms(fit3b)[[2]])] , fitted(fit3b), col="red" )
		points(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="blue", pch=3 ) # fit of previous mixed model
		sum(res^2)/nrow(dat) # mean residual squares		
						
		# no - same fit but heteroskedastic

		# epidemics?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster) + (m.outbreak_cat | cluster)", sep=""))
		fit3b <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3b)
		res <- dat[, as.character(terms(fit3b)[[2]])] - fitted(fit3b) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3b))
		histogram(res)		
		qqnorm(	residuals(fit3b)/sd(residuals(fit3b)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3b)/sd(residuals(fit3b)) )		
		plot(dat[, as.character(terms(fit3b)[[2]])] , fitted(fit3b), col="red" )
		points(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="blue", pch=3 ) # fit of previous mixed model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# only marginal improvement in fit, not worth it given greater complexity
		
		# livelihood?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster) + (livelihood | cluster)", sep=""))
		fit3b <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3b)
		res <- dat[, as.character(terms(fit3b)[[2]])] - fitted(fit3b) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3b))
		histogram(res)		
		qqnorm(	residuals(fit3b)/sd(residuals(fit3b)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3b)/sd(residuals(fit3b)) )		
		plot(dat[, as.character(terms(fit3b)[[2]])] , fitted(fit3b), col="red" )
		points(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="blue", pch=3 ) # fit of previous mixed model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# no, worse fit, so final model pending validation is:
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		

		
# Validation of best model
	
	# generate predictions (fixed effects only) from lme4 lmer function (based on Ben Bolker code in http://glmm.wikidot.com/faq
	f.predict.lmer <- function (f.fit, f.newdat) {
	
		mm <- model.matrix(terms(f.fit), f.newdat)
		return ( mm %*% fixef(fm1) )
	
	}
	
	# generate a numeric id for each survey
	dat[, "n.id"] <- seq(1:nrow(dat) )
		
	# function to perform Efron & Tibshirani (1993) bootstrapping cross-validation (note: known to under-estimate bias in some situations)
	f.xvalidate.boot <- function(f.dat, f.form, f.reffects) {
		# figure out number of observations in data
		n.obs <- nrow(f.dat)

		# figure out model weights
		if ( as.character(as.formula(f.form)[2]) %in% c("cdr.bct", "cdr_model_est", "ln.cdr") )    weight <- "cdr_survey_weight1"
		if ( as.character(as.formula(f.form)[2]) %in% c("u5dr.bct", "u5dr_model_est", "ln.u5dr") ) weight <- "u5dr_survey_weight1"
		
		# create a bootstrap sample by sampling from original data with replacement
		boot.id     <- sample(f.dat[, "n.id"], n.obs, replace=TRUE)
		boot.sample <- data.frame(f.dat[boot.id, ]) 

		# fit on bootstrap sample either a fixed effects only or a mixed effects model depending on function inputs
		if (f.reffects == "fixed")  {boot.fit <- try (do.call("lm"  , args = list(as.formula(f.form), data = boot.sample, weights = boot.sample[, weight] ) ),
													  silent=TRUE) }
		if (f.reffects == "random") {boot.fit <- try (do.call("lmer", args = list(as.formula(f.form), data = boot.sample, weights = boot.sample[, weight] ) ),
													  silent=TRUE) }  # try because model may fail
		
		# if model failed...
		if (class(boot.fit) == "try-error" ) {
			# return missing values
			return(c(NA, NA) )
		
		}
		# if model didn't fail...
		else
		{
			# calculate error of model on bootstrap dataset		
			if (f.reffects == "fixed")  {boot.error <- sum((boot.sample[, as.character(as.formula(f.form)[2])] - predict(boot.fit) )^2 , na.rm=TRUE) /
													   length(na.omit(predict(boot.fit))) }
			if (f.reffects == "random") {boot.error <- sum((boot.sample[, as.character(terms(boot.fit)[[2]])]
														   - model.matrix(terms(boot.fit), boot.sample) %*% fixef(boot.fit) )^2, na.rm=TRUE ) /
													   length(na.omit(model.matrix(terms(boot.fit), boot.sample) %*% fixef(boot.fit) )) }

			# calculate error of model when applied to original dataset (but need to remove observations in original dataset that don't exist in the bootstrap dataset
			if (f.reffects == "fixed")  {orig.error <- sum((f.dat[, as.character(as.formula(f.form)[2])] - predict(boot.fit, f.dat) )^2 , na.rm=TRUE) /
													   length(na.omit(predict(boot.fit, f.dat))) }
			if (f.reffects == "random") {orig.error <- sum((f.dat[, as.character(terms(boot.fit)[[2]])]
														   - model.matrix(terms(boot.fit), f.dat) %*% fixef(boot.fit) )^2, na.rm=TRUE ) /
													   length(na.omit(model.matrix(terms(boot.fit), f.dat) %*% fixef(boot.fit) )) }
	
			# return results of bootstrap iteration
			return(c(boot.error, orig.error) )
		}
	}
	
	# function to perform k-fold cross-validation (partition data in to k subsets, for each "fold" use all but one subset for model fitting and the remaining 1/k for testing fit) 
	# coding incomplete - do not use
#	f.xvalidate.kfold <- function(f.dat, f.form, f.reffects, f.k) {
#		# figure out number of observations in data
#		n.obs <- nrow(f.dat)
#
#		# figure out model weights
#		if ( as.character(as.formula(f.form)[2]) %in% c("cdr.bct", "cdr_model_est", "ln.cdr") )    weight <- "cdr_survey_weight1"
#		if ( as.character(as.formula(f.form)[2]) %in% c("u5dr.bct", "u5dr_model_est", "ln.u5dr") ) weight <- "u5dr_survey_weight1"
#
#		# starting and ending rows for each fold
#		rowstart <- 0
#		rowend   <- 0
#		
#		# split data into k subsets and perform validation on each
#		for (i in 1:f.k ) {# for each fold...
#			rowstart <- rowend + 1 # first row of test data for fold
#			rowend <- ifelse(i = f.k, nrow(f.dat), rowstart + nrow(f.dat) %/% f.k) # last row of test data for fold (also last row of dataset if last fold)
#			train.fit <- f.dat[-c(rowstart:rowend), ] # dataset on which model is fit
#			test.fit  <- f.dat[rowstart:rowend    , ]# dataset on which model is tested
#
#			# fit on training sample either a fixed effects only or a mixed effects model depending on function inputs
#			if (f.reffects == "fixed")  {kfold.fit <- do.call("lm"  , args = list(as.formula(f.form), data = train.fit, weights = train.fit[, weight] ) ) }
#			if (f.reffects == "random") {kfold.fit <- do.call("lmer", args = list(as.formula(f.form), data = train.fit, weights = train.fit[, weight] ) ) }
#
#			# use the model to make predictions based on the test data
#			if (f.reffects == "fixed")  {fold.error <- sum((test.fit[, as.character(as.formula(f.form)[2])] - predict(boot.fit, f.dat) )^2 , na.rm=TRUE) /
#													   length(na.omit(predict(boot.fit, f.dat))) }
#			if (f.reffects == "random") {fold.error <- sum((f.dat[, as.character(terms(boot.fit)[[2]])]
#															- model.matrix(terms(boot.fit), f.dat) %*% fixef(boot.fit) )^2, na.rm=TRUE ) /
#													   length(na.omit(model.matrix(terms(boot.fit), f.dat) %*% fixef(boot.fit) )) }
#			
#		
#		}
		
		

	# function to perform leave-one-out cross-validation (LOOCV) cross-validation (double-checked - gives same result as PRESS for fixed effects models)
	f.xvalidate.loocv <- function(f.dat, f.form, f.reffects) {
		
		# figure out model weights
		if ( as.character(as.formula(f.form)[2]) %in% c("cdr.bct", "cdr_model_est", "ln.cdr") )    weight <- "cdr_survey_weight1"
		if ( as.character(as.formula(f.form)[2]) %in% c("u5dr.bct", "u5dr_model_est", "ln.u5dr") ) weight <- "u5dr_survey_weight1"

		predicted <- c() # vector to hold predictions for model fit on each single observation used as external test datum		
		errors    <- c() # vector to hold rsquared residuals for model fit on each single observation used as external test datum
		
		for (i in 1:nrow(f.dat)) {	
			# which row?
			print(i)
			
			# subset the original data by excluding observation i: these are the training data on which model is fit
			dat.train <- f.dat[-i, ] 
				
			# fit on training data either a fixed effects only or a mixed effects model depending on function inputs
			if (f.reffects == "fixed")  {loocv.fit <- do.call("lm"  , args = list(as.formula(f.form), data = dat.train, weights = dat.train[, weight] ) ) }
			if (f.reffects == "random") {loocv.fit <- do.call("lmer", args = list(as.formula(f.form), data = dat.train, weights = dat.train[, weight] ) ) }

			# calculate prediction of model when applied to single excluded observation (test data), add to other errors for single test observations
			if (f.reffects == "fixed")  {predicted <- c(predicted , predict(loocv.fit, f.dat[i, ]) ) }
			if (f.reffects == "random") {predicted <- c(predicted , (model.matrix(terms(loocv.fit), f.dat) %*% fixef(loocv.fit) )[i] ) }
			
			# calculate squared residual of model when applied to single excluded observation (test data), add to other errors for single test observations
			if (f.reffects == "fixed")  {errors <- c(errors , (f.dat[i, as.character(as.formula(f.form)[2])] - predicted[i] )^2 ) }
			if (f.reffects == "random") {errors <- c(errors , (f.dat[i, as.character(terms(loocv.fit)[[2]])] - predicted[i] )^2 ) }
												 
			}

		# return predictions and squared residuals all observations when treated as test data (some are NAs as the training data may not have contained all the random effect grouping levels)
		out <- cbind(predicted, errors)
		colnames(out) <- c("predicted", "sq.residual")
		return(out)
		}
	
	
	# function to calculate model predictive power in terms of desired precision
	f.xvalidate.prec <- function(f.original, f.predicted, f.level) {
	
		# first output: vector where "yes" = prediction is within the specified precision level
		out1 <- ifelse(abs(f.original - f.predicted) <= f.level, "yes", "no")
		# second output: both data and predictions have been categorised into bins of width given by specified precision level, "yes" = they're in the same bin 
		out2 <- ifelse(as.factor(cut(f.original, seq(0, 10, by=f.level), include.lowest=TRUE) ) ==
		               as.factor(cut(f.predicted, seq(0, 10, by=f.level), include.lowest=TRUE) ),
			    "yes", "no")
	
		out<-cbind(out1, out2)
		colnames(out) <- c("within_level", "same_bin")
		return(out)
	}
	

	
	# Perform cross-validation on best fitting model
		# Bootstrap method  (100 bootstrap samples)
		fit3.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "random") } ) )
		colnames(fit3.xvalid.boot) <-c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit3.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		mean(res^2)						 # compare above to mean square residual error of model
		
			# model MSE = 0.0985 ; mean bootstrap MSE = 0.1343.  By comparison, fixed effects model (fit2b) had MSE=0.128 and PRESS=0.156.
		
		# LOOCV
		fit3.xvalid.loocv <- f.xvalidate.loocv(dat, form, "random")
		mean(na.omit(fit3.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
										                  # on individual observations after training it on remaining observations
		mean(res^2)						                  # compare to mean square residual error of model
		
			# model MSE = 0.0985 ; LOOCV RSS = 0.155.  By comparison, fixed effects model (fit2b) had MSE=0.128 and PRESS=0.156.
		
		# So model seems overfit, ultimately wouldn't predict much better than fixed effects model.
	
	# Go back to model with cluster as random effects, cross-validate
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (1 | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = cdr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# Bootstrap method  (100 bootstrap samples)
		fit3.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "random") } ) )
		colnames(fit3.xvalid.boot) <-c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit3.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		mean(res^2)						 # compare above to mean square residual error of model
		
			# model MSE = 0.107 ; mean bootstrap MSE = 0.140.  By comparison, fixed effects model (fit2b) had MSE=0.128 and PRESS=0.156.
		
		# LOOCV
		fit3.xvalid.loocv <- f.xvalidate.loocv(dat, form, "random")
		mean(na.omit(fit3.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
										                  # on individual observations after training it on remaining observations
		mean(res^2)						                  # compare to mean square residual error of model
	
			# model MSE = 0.107 ; LOOCV RSS = 0.151.  By comparison, fixed effects model (fit2b) had MSE=0.128 and PRESS=0.156.
		
		# So model seems overfit, ultimately wouldn't predict better than fixed effects model considering reduced degrees of freedom.		
		# Rough estimation of true R2 of mixed model:
		# R2_mixed_model = 1 + (MSE_mixed_model / MSE_fixed_model) * (R2_fixed_model - 1)
		# R2_mixed_true = 1 + (MSE_mixed_loocv / MSE_mixed_model) * (R2_mixed_model - 1)
		# Above doesn't take into account reduced d.f. in mixed model, so is a bit optimistic
	
		# Decision to include cluster as simple random effect dependent on relative performance of fixed vs. mixed U5DR model (both will be either fixed or mixed)
		
	
		
#.........................................................................................
### Predictive model for U5DR extrapolation (see also conceptual framework in report)

# Fit model for U5DR extrapolation

	#Box-Cox transformation of the dependent variable, based on best fixed effects model for CDR
		# fit best model so far but with untransformed dependent
		fit2b.un <- lm(u5dr_est_model ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )	
		
		# find ML lambda parameter for Box-Cox transformation of dependent
		bc  <- boxcox(fit2b.un, data = dat, plotit=FALSE)	
		u5dr.lambda <- bc$x[which.max(bc$y)] # gives lambda (=0.3)

		# generate u5dr Box-Cox transformed
		dat[, "u5dr.bct"] <- f.bct(dat[, "u5dr_est_model"] , u5dr.lambda) 	
		
		#rebuild model as above
			# Add all fixed effects
			fit1 <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
					   as.factor(livelihood) + y_mid + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )
			summary(fit1)
			plot(residuals(fit1), fitted(fit1))
			histogram(residuals(fit1))
			qqnorm(	residuals(fit1)/sd(residuals(fit1)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit1)/sd(residuals(fit1)) )
			plot(dat[, as.character(formula(fit1)[2])] , fitted(fit1) )
			
				# possible tweaks in fixed effects
					#year as categorical?
					fit1b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat),
								data = dat, weights = u5dr_survey_weight1
								)	
					summary(fit1b)
					plot(residuals(fit1b), fitted(fit1b))
					histogram(residuals(fit1b))
					qqnorm(	residuals(fit1b)/sd(residuals(fit1b)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1b)/sd(residuals(fit1b)) )
					plot(dat[, as.character(formula(fit1b)[2])] , fitted(fit1b) )
				
					#yes - also add season?
					fit1c <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.m_mid_cat),
								data = dat, weights = u5dr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )

					#no - replace AToT with RToT?
					fit1c <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.RToT_liv_lag2_cat),
								data = dat, weights = u5dr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )

					#no
					# also add other lag effects for AToT and WFP presence?
					fit1c <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + wfp_present_lag2 + wfp_present_lag5 +
								as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + as.factor(m.AToTw_lag2_cat) + as.factor(m.AToTw_lag5_cat),
								data = dat, weights = u5dr_survey_weight1
								)	
					summary(fit1c)
					plot(residuals(fit1c), fitted(fit1c))
					histogram(residuals(fit1c))
					qqnorm(	residuals(fit1c)/sd(residuals(fit1c)), xlim=c(-4,4), ylim=c(-4,4) )
					qqline( residuals(fit1c)/sd(residuals(fit1c)) )
					plot(dat[, as.character(formula(fit1c)[2])] , fitted(fit1c) )
					
					# no - 3% improvement in R2 not enough gain for more complex model
					
			# Add possible effect modifications (see report conceptual framework)
				# WFP presence x AToT
				fit2 <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# no - season x AToT		
				fit2 <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat)
						   + m.m_mid_cat * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# R2 improves somewhat but model becomes complex, QQ plot less normal, so no
				# livelihood x AToT				
				fit2 <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood) * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
				
				# same as above
				# epidemics x location				
				fit2 <- lm(u5dr.bct ~ as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.location) * as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )

				# same as above
				# conflict incidents x epidemics
				fit2 <- lm(u5dr.bct ~ as.factor(y_mid) + as.factor(m.location) * 
						   as.factor(m.rate_incidents_lag3_cat) + as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat)
						   + as.factor(livelihood),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2)
				plot(residuals(fit2), fitted(fit2))
				histogram(residuals(fit2))
				qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2)/sd(residuals(fit2)) )		
				plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
				
				# same as above
				
			# fixed effects model so far
			fit2 <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
					   as.factor(livelihood) + as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )
			summary(fit2)
			plot(residuals(fit2), fitted(fit2))
			histogram(residuals(fit2))
			qqnorm(	residuals(fit2)/sd(residuals(fit2)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2)/sd(residuals(fit2)) )		
			plot(dat[, as.character(formula(fit2)[2])] , fitted(fit2) )
			sum(residuals(fit2)^2)/nrow(dat) # mean residual squares
			
				# is it overfitted? is the predictive power optimistic? do cross-validation to check
					# calculate press
					press(fit2)
					# compared to sum of squares of model
					sum(residuals(fit2)^2)
					
			# some optimism bias (possible overfitting), so try to reduce model		
				# take out livelihood?
				fit2b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + 
						   as.factor(y_mid) + as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2b)
				plot(residuals(fit2b), fitted(fit2b))
				histogram(residuals(fit2b))
				qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
				plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
				sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
				press(fit2b)
				sum(residuals(fit2b)^2)
				anova (fit2b, fit2)
				
				# no (R2 stays the same but QQ plot becomes less normal), but take out year?
				fit2b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 + as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2b)
				plot(residuals(fit2b), fitted(fit2b))
				histogram(residuals(fit2b))
				qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
				plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
				sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares
				press(fit2b)
				sum(residuals(fit2b)^2)
				anova (fit2b, fit2)
				
				# yes - also take out conflict incidents?
				fit2c <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
				summary(fit2c)
				plot(residuals(fit2c), fitted(fit2c))
				histogram(residuals(fit2c))
				qqnorm(	residuals(fit2c)/sd(residuals(fit2c)), xlim=c(-4,4), ylim=c(-4,4) )
				qqline( residuals(fit2c)/sd(residuals(fit2c)) )		
				plot(dat[, as.character(formula(fit2c)[2])] , fitted(fit2c) )
				sum(residuals(fit2c)^2)/nrow(dat) # mean residual squares
				press(fit2c)
				sum(residuals(fit2c)^2)
				anova (fit2c, fit2b)
				
				# no			
						
			# decide to put WFP x AToT effect modification back in just to be consistent with CDR model (and because it slightly improves fit; also more plausible biologically)
			fit2b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )
			summary(fit2b)
			plot(residuals(fit2b), fitted(fit2b))
			histogram(residuals(fit2b))
			qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
			plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
			sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares (MSE)
			press(fit2b) # predicted MSE if model were applied to other data for prediction
			sum(residuals(fit2b)^2)						
				
		
			# so this is the fixed effects model:
			fit2b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )
			summary(fit2b)
			plot(residuals(fit2b), fitted(fit2b))
			histogram(residuals(fit2b))
			qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
			plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
			sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares (MSE)
			press(fit2b) # predicted MSE if model were applied to other data for prediction
			sum(residuals(fit2b)^2)


	# Add cluster as random effect?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (1| cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = u5dr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# yes - fit improved (graphically)
		
	# Try other random effects grouped by cluster:
		# AToT?
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = u5dr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
				
		# yes - further improvement in fit, residuals still normal
		
		# so final model pending validation is:
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (m.AToTw_lag2_cat | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = u5dr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		

		
	# Perform cross-validation on best fitting model
		# Bootstrap method  (100 bootstrap samples)
		fit3.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "random") } ) )
		colnames(fit3.xvalid.boot) <-c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit3.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		mean(res^2)						 # compare above to mean square residual error of model
		
			# model MSE = 0.342 ; mean bootstrap MSE = 0.624.  By comparison, fixed effects model (fit2b) had MSE=0.547 and PRESS=0.659.
		
		# LOOCV
		fit3.xvalid.loocv <- f.xvalidate.loocv(dat, form, "random")
		mean(na.omit(fit3.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
										                  # on individual observations after training it on remaining observations
		mean(res^2)						                  # compare to mean square residual error of model
			
			# model MSE = 0.342 ; LOOCV RSS = 0.665.  By comparison, fixed effects model (fit2b) had MSE=0.547 and PRESS=0.659.
		
		# So model seems overfit, ultimately wouldn't predict better than fixed effects model.
	
	# Go back to model with cluster as random effects, cross-validate
		form <- as.formula(paste(formula(fit2b)[2], "~ ",formula(fit2b)[3] , " + (1 | cluster)", sep=""))
		fit3 <- lmer(form, data = dat, weights = u5dr_survey_weight1)
		summary(fit3)
		res <- dat[, as.character(terms(fit3)[[2]])] - fitted(fit3) # residuals (unweighted unlike model output) 
		plot(res, fitted(fit3))
		histogram(res)		
		qqnorm(	residuals(fit3)/sd(residuals(fit3)), xlim=c(-4,4), ylim=c(-4,4) )
		qqline( residuals(fit3)/sd(residuals(fit3)) )		
		plot(dat[, as.character(terms(fit3)[[2]])] , fitted(fit3), col="red" )
		points(dat[, as.character(terms(fit2b)[[2]])] , fitted(fit2b), col="blue", pch=3 ) # fit of fixed effects model
		sum(res^2)/nrow(dat) # mean residual squares		
		
		# Bootstrap method  (100 bootstrap samples)
		fit3.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "random") } ) )
		colnames(fit3.xvalid.boot) <-c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit3.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		mean(res^2)						 # compare above to mean square residual error of model
		
			# model MSE = 0.401 ; mean bootstrap MSE = 0.599.  By comparison, fixed effects model (fit2b) had MSE=0.547 and PRESS=0.659.
		
		# LOOCV
		fit3.xvalid.loocv <- f.xvalidate.loocv(dat, form, "random")
		mean(na.omit(fit3.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
										                  # on individual observations after training it on remaining observations
		mean(res^2)						                  # compare to mean square residual error of model
	
			# model MSE = 0.401 ; LOOCV RSS = 0.640.  By comparison, fixed effects model (fit2b) had MSE=0.547 and PRESS=0.659.
			
		# So model seems overfit, ultimately wouldn't predict better than fixed effects model considering reduced degrees of freedom.		
		# Rough estimation of true R2 of mixed model:
		# R2_mixed_model = 1 + (MSE_mixed_model / MSE_fixed_model) * (R2_fixed_model - 1) = 0.83
		# R2_mixed_true = 1 + (MSE_mixed_loocv / MSE_mixed_model) * (R2_mixed_model - 1) = 0.729
		# Above doesn't take into account reduced d.f. in mixed model, so is a bit optimistic
	
		# DECISION: LEAVE OUT RANDOM EFFECTS, INCLUDE ONLY FIXED EFFECTS
		
		# Final tweak: change Box-Cox transformation to lambda = 0.4 to be consistent with CDR model, since result is practically unchanged:
			u5dr.lambda <- cdr.lambda
			dat[, "u5dr.bct"] <- f.bct(dat[, "u5dr_est_model"], u5dr.lambda)
			fit2b <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
					   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
					   data = dat, weights = u5dr_survey_weight1
					   )
			summary(fit2b)
			plot(residuals(fit2b), fitted(fit2b))
			histogram(residuals(fit2b))
			qqnorm(	residuals(fit2b)/sd(residuals(fit2b)), xlim=c(-4,4), ylim=c(-4,4) )
			qqline( residuals(fit2b)/sd(residuals(fit2b)) )		
			plot(dat[, as.character(formula(fit2b)[2])] , fitted(fit2b) )
			sum(residuals(fit2b)^2)/nrow(dat) # mean residual squares (MSE)
			press(fit2b) # predicted MSE if model were applied to other data for prediction
			sum(residuals(fit2b)^2)
		
		
#.........................................................................................
### Final predictive models for extrapolation

# CDR extrapolation model
	fit.cdr.extr <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )
	summary(fit.cdr.extr)
	
	# model diagnostics
		windowsFonts(Calibri=windowsFont("Calibri"))
		par(family="Calibri")
		par(mfrow=c(2,2), mar=c(5,4,2,1), oma=c(1,1,1,1))
		
		# heteroskedasticity plot:
		plot(fitted(fit.cdr.extr), residuals(fit.cdr.extr), xlab="fitted values", ylab="residuals", col="red", cex.main=1,
		     main = "residuals vs. fitted values")
		abline(a=0, b=0, h=c(-4,4), lty=3, col="grey")

		# histogram of residuals:
		hist(residuals(fit.cdr.extr), xlab="residuals", ylab="percent of total", col="grey", cex.main=1,
		          main = "distribution of residuals")
		
		# Q-Q plot:
		qqnorm(residuals(fit.cdr.extr)/sd(residuals(fit.cdr.extr)), xlim=c(-4,4), ylim=c(-4,4) , main = "quantile-quantile plot of residuals", 
		      ylab="standardised residual quantiles", xlab="theoretical quantiles", col="red", cex.main=1)
		qqline(residuals(fit.cdr.extr)/sd(residuals(fit.cdr.extr)) , lty=3, col="grey" )		
		
		# prediction plot:
		plot(dat[, as.character(formula(fit.cdr.extr)[2])] , fitted(fit.cdr.extr), main = "predictions vs. data", xlim=c(-1.5,2), ylim=c(-1.5,2) , 
         	 xlab="data (Box-Cox transformed)", ylab="model predictions", col="blue", cex.main=1)
		abline(a=0, b=1, lty=3, col="grey")
		
		# save plot
		savePlot("graph_cdr_extr_diag.wmf",type="wmf") 
		
	# cross-validation statistics:
		press(fit.cdr.extr)/nrow(dat) 			 # predicted MSE if model were applied to other data for prediction
		sum(residuals(fit.cdr.extr)^2)/nrow(dat) # compared to model MSE
		
		form <- as.formula(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat) )
		# Bootstrap method:
		fit.cdr.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "fixed") } ) )
		colnames(fit.cdr.xvalid.boot) <- c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit.cdr.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		sum(residuals(fit.cdr.extr)^2)/nrow(dat)  # compare above to mean square residual error of model
		
		# LOOCV method:
		fit.cdr.xvalid.loocv <- f.xvalidate.loocv(dat, form, "fixed")
		mean(na.omit(fit.cdr.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
															 # on individual observations after training it on remaining observations
		sum(residuals(fit.cdr.extr)^2)/nrow(dat)			 # compare to mean square residual error of model

			# expected precision on external data (given absolute precision level of 1 death per 10,000 per day):
			fit.cdr.xvalid.prec <- f.xvalidate.prec(f.bctback(dat[, "cdr.bct"], dat[, "cdr_est_model"], cdr.lambda),
													f.bctback(fit.cdr.xvalid.loocv[, "predicted"], dat[, "cdr_est_model"], cdr.lambda),
													1.0
													)
			fit.cdr.xvalid.prec <- as.data.frame(fit.cdr.xvalid.prec)
			nrow(subset(fit.cdr.xvalid.prec, within_level=="yes")) / nrow(fit.cdr.xvalid.prec) # proportion of predicted values within precision level
			nrow(subset(fit.cdr.xvalid.prec,     same_bin=="yes")) / nrow(fit.cdr.xvalid.prec) # proportion of predicted values within same bin as data
																							   # (bin size defined by precision level)
																							   
				# compare to precision on training data (given absolute precision level of 1 death per 10,000 per day):
				fit.cdr.xvalid.prec.int <- f.xvalidate.prec(f.bctback(dat[, "cdr.bct"], dat[, "cdr_est_model"], cdr.lambda),
														f.bctback(fitted(fit.cdr.extr), dat[, "cdr_est_model"], cdr.lambda),
														1.0
														)
				fit.cdr.xvalid.prec.int <- as.data.frame(fit.cdr.xvalid.prec.int)
				nrow(subset(fit.cdr.xvalid.prec.int, within_level=="yes")) / nrow(fit.cdr.xvalid.prec.int) # proportion of predicted values within precision level
				nrow(subset(fit.cdr.xvalid.prec.int,     same_bin=="yes")) / nrow(fit.cdr.xvalid.prec.int) # proportion of predicted values within same bin as data
																										   # (bin size defined by precision level)				
					
				
			# expected precision on external data (given absolute precision level of 0.5 deaths per 10,000 per day):
			fit.cdr.xvalid.prec <- f.xvalidate.prec(f.bctback(dat[, "cdr.bct"], dat[, "cdr_est_model"], cdr.lambda),
													f.bctback(fit.cdr.xvalid.loocv[, "predicted"], dat[, "cdr_est_model"], cdr.lambda),
													0.5
													)
			fit.cdr.xvalid.prec <- as.data.frame(fit.cdr.xvalid.prec)
			nrow(subset(fit.cdr.xvalid.prec, within_level=="yes")) / nrow(fit.cdr.xvalid.prec) # proportion of predicted values within precision level
			nrow(subset(fit.cdr.xvalid.prec,     same_bin=="yes")) / nrow(fit.cdr.xvalid.prec) # proportion of predicted values within same bin as data
																							   # (bin size defined by precision level)

				# compare to precision on training data (given absolute precision level of 0.5 deaths per 10,000 per day):
				fit.cdr.xvalid.prec.int <- f.xvalidate.prec(f.bctback(dat[, "cdr.bct"], dat[, "cdr_est_model"], cdr.lambda),
														f.bctback(fitted(fit.cdr.extr), dat[, "cdr_est_model"], cdr.lambda),
														0.5
														)
				fit.cdr.xvalid.prec.int <- as.data.frame(fit.cdr.xvalid.prec.int)
				nrow(subset(fit.cdr.xvalid.prec.int, within_level=="yes")) / nrow(fit.cdr.xvalid.prec.int) # proportion of predicted values within precision level
				nrow(subset(fit.cdr.xvalid.prec.int,     same_bin=="yes")) / nrow(fit.cdr.xvalid.prec.int) # proportion of predicted values within same bin as data
																										   # (bin size defined by precision level)				
					
			# expected R-squared when used on external data
				1 + (press(fit.cdr.extr) / sum(residuals(fit.cdr.extr)^2)) * (summary(fit.cdr.extr)$adj.r.squared  - 1)

				
																							   
# U5DR extrapolation model
	fit.u5dr.extr <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )
	summary(fit.u5dr.extr)
	
	# model diagnostics
		windowsFonts(Calibri=windowsFont("Calibri"))
		par(family="Calibri")
		par(mfrow=c(2,2), mar=c(5,4,2,1), oma=c(1,1,1,1))
		
		# heteroskedasticity plot:
		plot(fitted(fit.u5dr.extr), residuals(fit.u5dr.extr), xlab="fitted values", ylab="residuals", col="red", cex.main=1,
		     main = "residuals vs. fitted values")
		abline(a=0, b=0, h=c(-4,4), lty=3, col="grey")

		# histogram of residuals:
		hist(residuals(fit.u5dr.extr), xlab="residuals", ylab="percent of total", col="grey", cex.main=1,
		          main = "distribution of residuals")
		
		# Q-Q plot:
		qqnorm(residuals(fit.u5dr.extr)/sd(residuals(fit.u5dr.extr)), xlim=c(-4,4), ylim=c(-4,4) , main = "quantile-quantile plot of residuals", 
		      ylab="standardised residual quantiles", xlab="theoretical quantiles", col="red", cex.main=1)
		qqline(residuals(fit.u5dr.extr)/sd(residuals(fit.u5dr.extr)) , lty=3, col="grey" )		
		
		# prediction plot:
		plot(dat[, as.character(formula(fit.u5dr.extr)[2])] , fitted(fit.u5dr.extr), main = "predictions vs. data", xlim=c(-1.5,6), ylim=c(-1.5,6), 
         	 xlab="data (Box-Cox transformed)", ylab="model predictions", col="blue", cex.main=1)
		abline(a=0, b=1, lty=3, col="grey")
		
		# save plot
		savePlot("graph_u5dr_extr_diag.wmf",type="wmf") 
			
	# cross-validation statistics:
		press(fit.u5dr.extr)/nrow(dat) 			 # predicted MSE if model were applied to other data for prediction
		sum(residuals(fit.u5dr.extr)^2)/nrow(dat) # compared to model MSE
		
		form <- as.formula(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat) )
		# Bootstrap method:
		fit.u5dr.xvalid.boot <- t(replicate(100, {f.xvalidate.boot(dat, form, "fixed") } ) )
		colnames(fit.u5dr.xvalid.boot) <- c("MSE_bootstrap_sample", "MSE_original_data")
		colMeans(fit.u5dr.xvalid.boot, na.rm=TRUE) # look at second column: this is the predicted mean error for prediction
		sum(residuals(fit.u5dr.extr)^2)/nrow(dat)  # compare above to mean square residual error of model
		
		# LOOCV method:
		fit.u5dr.xvalid.loocv <- f.xvalidate.loocv(dat, form, "fixed")
		mean(na.omit(fit.u5dr.xvalid.loocv[, "sq.residual"])) # mean square residual error of fitting model
															 # on individual observations after training it on remaining observations
		sum(residuals(fit.u5dr.extr)^2)/nrow(dat)			 # compare to mean square residual error of model

			# expected precision on external data (given absolute precision level of 1 death per 10,000 per day):
			fit.u5dr.xvalid.prec <- f.xvalidate.prec(f.bctback(dat[, "u5dr.bct"], dat[, "u5dr_est_model"], u5dr.lambda),
													f.bctback(fit.u5dr.xvalid.loocv[, "predicted"], dat[, "u5dr_est_model"], u5dr.lambda),
													1.0
													)
			fit.u5dr.xvalid.prec <- as.data.frame(fit.u5dr.xvalid.prec)
			nrow(subset(fit.u5dr.xvalid.prec, within_level=="yes")) / nrow(fit.u5dr.xvalid.prec) # proportion of predicted values within precision level
			nrow(subset(fit.u5dr.xvalid.prec,     same_bin=="yes")) / nrow(fit.u5dr.xvalid.prec) # proportion of predicted values within same bin as data
																							   # (bin size defined by precision level)
																							   
				# compare to precision on training data (given absolute precision level of 1 death per 10,000 per day):
				fit.u5dr.xvalid.prec.int <- f.xvalidate.prec(f.bctback(dat[, "u5dr.bct"], dat[, "u5dr_est_model"], u5dr.lambda),
														f.bctback(fitted(fit.u5dr.extr), dat[, "u5dr_est_model"], u5dr.lambda),
														1.0
														)
				fit.u5dr.xvalid.prec.int <- as.data.frame(fit.u5dr.xvalid.prec.int)
				nrow(subset(fit.u5dr.xvalid.prec.int, within_level=="yes")) / nrow(fit.u5dr.xvalid.prec.int) # proportion of predicted values within precision level
				nrow(subset(fit.u5dr.xvalid.prec.int,     same_bin=="yes")) / nrow(fit.u5dr.xvalid.prec.int) # proportion of predicted values within same bin as data
																										   # (bin size defined by precision level)				
					
				
			# expected precision on external data (given absolute precision level of 0.5 deaths per 10,000 per day):
			fit.u5dr.xvalid.prec <- f.xvalidate.prec(f.bctback(dat[, "u5dr.bct"], dat[, "u5dr_est_model"], u5dr.lambda),
													f.bctback(fit.u5dr.xvalid.loocv[, "predicted"], dat[, "u5dr_est_model"], u5dr.lambda),
													0.5
													)
			fit.u5dr.xvalid.prec <- as.data.frame(fit.u5dr.xvalid.prec)
			nrow(subset(fit.u5dr.xvalid.prec, within_level=="yes")) / nrow(fit.u5dr.xvalid.prec) # proportion of predicted values within precision level
			nrow(subset(fit.u5dr.xvalid.prec,     same_bin=="yes")) / nrow(fit.u5dr.xvalid.prec) # proportion of predicted values within same bin as data
																							   # (bin size defined by precision level)

				# compare to precision on training data (given absolute precision level of 0.5 deaths per 10,000 per day):
				fit.u5dr.xvalid.prec.int <- f.xvalidate.prec(f.bctback(dat[, "u5dr.bct"], dat[, "u5dr_est_model"], u5dr.lambda),
														f.bctback(fitted(fit.u5dr.extr), dat[, "u5dr_est_model"], u5dr.lambda),
														0.5
														)
				fit.u5dr.xvalid.prec.int <- as.data.frame(fit.u5dr.xvalid.prec.int)
				nrow(subset(fit.u5dr.xvalid.prec.int, within_level=="yes")) / nrow(fit.u5dr.xvalid.prec.int) # proportion of predicted values within precision level
				nrow(subset(fit.u5dr.xvalid.prec.int,     same_bin=="yes")) / nrow(fit.u5dr.xvalid.prec.int) # proportion of predicted values within same bin as data
																										   # (bin size defined by precision level)				
					
			# expected R-squared when used on external data
				1 + (press(fit.u5dr.extr) / sum(residuals(fit.u5dr.extr)^2)) * (summary(fit.u5dr.extr)$adj.r.squared  - 1)


# Save analysis dataset
write.csv(dat, "survey_metadata_analysed.csv")



