#........................................................................................................
### ~~ R CODE TO CREATE TIME SERIES OF ANALYSIS STRATA FOR SOMALIA DEATH TOLL ANALYSIS (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (January 2013)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis") #office

# read data
strata <- read.csv("analysis_strata.csv")
surveys <- read.csv("survey_metadata.csv") # survey metadata
td <- read.csv("tseries_districts.csv") # district time series
refugee.mortality <- read.csv("refugee_mortality.csv") # projected death rates in refugee camps
epidemics <- read.csv("epidemics.csv") # outbreak occurrence data
year <- seq(2006, 2012, 1) #sequence of years
month <- seq(1, 12, 1) #sequence of months
# pop1 <- read.csv("pop1.csv") # population of Somalia and Ethiopia camps (first version from JHU)
# pop1_kenya <- read.csv("pop1_kenya.csv") # population of Kenya camps (first version from JHU)
# pop2 <- read.csv("pop2.csv") # population of Somalia and Ethiopia camps (second version)
# pop2_kenya <- read.csv("pop2_kenya.csv") # population of Kenya camps (same as pop1)
pop3 <- read.csv("pop3.csv") # population of Somalia and Ethiopia camps (third and final version)
pop3_kenya <- read.csv("pop3_kenya.csv") # population of Kenya camps (same as pop1)

#.........................................................................................
### Create time series of strata

# create time series
tst <- expand.grid(strata[, "stratum"], month, year)
colnames(tst) <- c("stratum", "m", "y")

tst <- merge(tst, strata[ , c("stratum", "location", "region", "livelihood", "district1", "district2", "district3", "district4", 
							  "district5", "district6", "district7", "backup_district1", "backup_district2")] ,
		     by="stratum"
			)

# sort time series
tst <- tst[order(tst[, "stratum"], tst[, "y"], tst[, "m"]), ]

# add month from 1 to end of time series for each stratum
tst[, "tm"] <- rep(seq(1, length(year)*length(month), 1), nrow(strata) )


#.........................................................................................
### Add ACLED conflict incidents data by district

# function that computes incident rate over a stratum
f.tst.conflict <- function(f.tst, f.td) {

	# cumulative events and person-time denominators
	events <- 0
	ptime  <- 0
	
	# for each district...
	for (i in f.tst[c("district1", "district2", "district3", "district4", "district5", "district6", "district7")] ) {

		#which district?
		dis <- as.character(i)
	
		# if district is not null...
		if (dis != "") {

			# add events and person-time from that district to the cumulative total			
			events <- events + subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, "n_incidents"]
			ptime  <- ptime  + subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, "pop_undp_proj"]

			}
		 }
	
	# return event rate per 100,000 person-months
	return(as.numeric(events * 100000 / ptime))

	}

# compute incident rate  for each stratum-month
tst[, "rate_incidents"] <- apply(tst, 1, f.tst.conflict, td)
	
	

#.........................................................................................
### Add ToT variables based on district time series

# function that computes weighted mean ToT over a stratum
f.tst.tot <- function(f.tst, f.td) {

	# output
	out <- c(NA, NA, NA, NA)
	
	# for each ToT index...
	for (i in c("AToTw", "AToTg", "RToTw", "RToTg") ) {

		# district values to be averaged
		x <- c()
		# weights
		w <- c()
		
		# for each district...
		for (j in f.tst[c("district1", "district2", "district3", "district4",
		                  "district5", "district6", "district7", "backup_district1", "backup_district2")] ) {

				#which district?
				dis <- as.character(j)
	
				# if district is not null...
				if (dis != "") {

					# add ToT values and their weights to list
					x <- c(x, subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, i] )
					w <- c(w, subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, "pop_undp_proj_urb"] )

				}
			}
				
		#compute weighted mean of all districts for this ToT index
		out[match(i, c("AToTw", "AToTg", "RToTw", "RToTg") )] <- weighted.mean(x, w, na.rm=TRUE)

		}	

	return(out)
	
	}

	
# compute ToT indices for each stratum-month
tst[ , c("AToTw", "AToTg", "RToTw", "RToTg")] <- t(apply(tst, 1, f.tst.tot, td) )

# attribute livelihood-specific RToT
tst[, "RToT_liv"] <- ifelse(tst[, "livelihood"] == "pastoral", tst[, "RToTg"], tst[, "RToTw"] )


						   
#.........................................................................................
###Add information on WFP presence

# function that computes whether WFP was mostly present in the stratum
f.tst.wfp <- function(f.tst, f.td) {

	# count of district-months with WFP presence
	wfp <- 0
	
	# number of potential district-months of WFP presence
	wfp.pot <- 0
	
	# for each district...
	for (i in f.tst[c("district1", "district2", "district3", "district4", "district5", "district6", "district7")]) {
	
		#which district?
		dis <- as.character(i)
			
		# add district-months with WFP presence to the cumulative total
		wfp <- wfp + nrow(subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) & wfp_present=="yes") )
			
		# add potential district-months to the cumulative total
		wfp.pot <- wfp.pot + nrow(subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) ) )
			
		}
	
	# return "yes" if the cumulative districts-months with WFP are >= 1/2 of the total district-months
	if ( (wfp / (wfp.pot - 0.01) ) >= 0.5 ) return("yes") else return("no")  # small - 0.001 avoids problem of denominator 0 in Kenya/Ethiopia camps

	}


# compute WFP presence for each stratum-month
tst[ , "wfp_present"] <- apply(tst, 1, f.tst.wfp, td)	



#.........................................................................................
### Add Consumer Price Index data

# function that computes weighted average CPI over a stratum
f.tst.cpi <- function(f.tst, f.td) {

	# district values to be averaged
	x <- c()
	# weights
	w <- c()
	
	# for each district...
	for (i in f.tst[c("district1", "district2", "district3", "district4", "district5",
	                  "district6", "district7", "backup_district1", "backup_district2")] ) {

		#which district?
		dis <- as.character(i)
	
		# if district is not null...
		if (dis != "") {

			# add CPI values to the list			
			x <- c(x, subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, "s_cpi"] )
			w <- c(w, subset(f.td, district == dis & tm == as.numeric(f.tst[["tm"]]) )[, "pop_undp_proj_urb"] )

			}
		 }
	
	# return weighted CPI average over stratum
	return(weighted.mean (x, w, na.rm=TRUE) )

	}

# compute CPI for each stratum-month
tst[ , "s_cpi"] <- apply(tst, 1, f.tst.cpi, td)	
	


#.........................................................................................
### Add data on epidemics

tst <- merge(tst, epidemics, by=c("stratum", "m", "y"), all.x=TRUE)
	
	
#.........................................................................................
### Add survey mortality and malnutrition data (excluding refugee camps)

## Mortality merging

# restrict survey metadata to relevant variables only
surveys <- surveys[, c("survey_id", "y_survey", "m_survey", "stratum1", "stratum2", "stratum3", "stratum4", "stratum1_cov", "stratum2_cov",
					   "stratum3_cov", "stratum4_cov",
					   "district_spec", "geo_other", "gam_whz_who", "sam_whz_who", "gam_whz_nchs", "sam_whz_nchs", "gam_muac", "sam_muac_110",
					   "sam_muac_115", "oedema", "pregnant_gam_muac", "recall_months", "eligible_mortality", "eligible_anthropometry", 
					   "cdr_est_model", "cdr_lci_model", "cdr_uci_model", "ln_cdr_se", "cdr_survey_weight1", 
					   "u5dr_est_model", "u5dr_lci_model", "u5dr_uci_model", "ln_u5dr_se", "u5dr_survey_weight1"
					   )
				  ]

# verticalise dataset into dataset with one line = one stratum / keep only relevant variables
s1 <- subset(surveys, select = -c(stratum2, stratum3, stratum4, stratum2_cov, stratum3_cov, stratum4_cov) )
s2 <- subset(surveys, select = -c(stratum1, stratum3, stratum4, stratum1_cov, stratum3_cov, stratum4_cov) )
s3 <- subset(surveys, select = -c(stratum1, stratum2, stratum4, stratum1_cov, stratum2_cov, stratum4_cov) )
s4 <- subset(surveys, select = -c(stratum1, stratum2, stratum3, stratum1_cov, stratum2_cov, stratum3_cov) )

colnames(s1)[4:5] <- c("stratum", "stratum_cov") 
colnames(s2)[4:5] <- c("stratum", "stratum_cov") 
colnames(s3)[4:5] <- c("stratum", "stratum_cov") 
colnames(s4)[4:5] <- c("stratum", "stratum_cov") 

s <- rbind(s1, s2, s3, s4)
head(s[, 1:10])

s <- subset(s, stratum!="")

# create mortality dataset for merging
s_mortality <- subset(s, eligible_mortality=="yes")[, c("survey_id", "y_survey", "m_survey", "stratum", "stratum_cov", "recall_months", 
														"cdr_est_model", "cdr_lci_model", "cdr_uci_model", "ln_cdr_se", "cdr_survey_weight1", 
														"u5dr_est_model", "u5dr_lci_model", "u5dr_uci_model", "ln_u5dr_se",
														"u5dr_survey_weight1"
														)
	
												   ]
	# create time variable
	s_mortality[, "tm"] <- (s_mortality[, "y_survey"] - year[1] ) * length(month) + s_mortality[, "m_survey"]
												   
	#identify mortality duplicates (i.e. surveys that cover the same stratum and whose recall period overlaps)

	s_mortality <- s_mortality[order(s_mortality[, "stratum"], s_mortality[, "tm"], s_mortality[, "survey_id"] ), ]

	dupl_m <- rep(1, nrow(s_mortality) )

	for (i in 2:nrow(s_mortality) ) {

			if ( ( (s_mortality[i, "tm"] - s_mortality[i, "recall_months"]) < s_mortality[i-1, "tm"]) & (s_mortality[i, "stratum"] == s_mortality[i-1, "stratum"]) )
				dupl_m[i] <- dupl_m[i-1] + 1 else dupl_m[i] <- 1 
			
		}

	s_mortality[, "dupl"] <- dupl_m
	
	table(s_mortality[, "dupl"])

	# create separate datasets for duplicates
	s_merge1 <- subset(s_mortality, dupl==1, select=-c(dupl, y_survey, m_survey) )
	s_merge2 <- subset(s_mortality, dupl==2, select=-c(dupl, y_survey, m_survey) )
	s_merge3 <- subset(s_mortality, dupl==3, select=-c(dupl, y_survey, m_survey) )
	s_merge4 <- subset(s_mortality, dupl==4, select=-c(dupl, y_survey, m_survey) )
	s_merge5 <- subset(s_mortality, dupl==5, select=-c(dupl, y_survey, m_survey) )
	s_merge6 <- subset(s_mortality, dupl==6, select=-c(dupl, y_survey, m_survey) )
	
	# rename columns to prepare for merging
	colnames(s_merge1) <- c("survey_id1", "stratum", "stratum_cov1", "recall_months1", "cdr_est_model1",
							"cdr_lci_model1", "cdr_uci_model1", "ln_cdr_se1", "cdr_survey_weight11",
							"u5dr_est_model1", "u5dr_lci_model1", "u5dr_uci_model1", "ln_u5dr_se1", "u5dr_survey_weight11", "tm")
	colnames(s_merge2) <- c("survey_id2", "stratum", "stratum_cov2", "recall_months2", "cdr_est_model2", 
							"cdr_lci_model2", "cdr_uci_model2", "ln_cdr_se2", "cdr_survey_weight12",
							"u5dr_est_model2", "u5dr_lci_model2", "u5dr_uci_model2", "ln_u5dr_se2", "u5dr_survey_weight12", "tm")
	colnames(s_merge3) <- c("survey_id3", "stratum", "stratum_cov3", "recall_months3", "cdr_est_model3",
							"cdr_lci_model3", "cdr_uci_model3", "ln_cdr_se3", "cdr_survey_weight13",
							"u5dr_est_model3", "u5dr_lci_model3", "u5dr_uci_model3", "ln_u5dr_se3", "u5dr_survey_weight13", "tm")
	colnames(s_merge4) <- c("survey_id4", "stratum", "stratum_cov4", "recall_months4", "cdr_est_model4", 
							"cdr_lci_model4", "cdr_uci_model4", "ln_cdr_se4", "cdr_survey_weight14",
							"u5dr_est_model4", "u5dr_lci_model4", "u5dr_uci_model4", "ln_u5dr_se4", "u5dr_survey_weight14", "tm")
	colnames(s_merge5) <- c("survey_id5", "stratum", "stratum_cov5", "recall_months5", "cdr_est_model5", 
							"cdr_lci_model5", "cdr_uci_model5", "ln_cdr_se5", "cdr_survey_weight15",
							"u5dr_est_model5", "u5dr_lci_model5", "u5dr_uci_model5", "ln_u5dr_se5", "u5dr_survey_weight15", "tm")
	colnames(s_merge6) <- c("survey_id6", "stratum", "stratum_cov6", "recall_months6", "cdr_est_model6", 
							"cdr_lci_model6", "cdr_uci_model6", "ln_cdr_se6", "cdr_survey_weight16",
							"u5dr_est_model6", "u5dr_lci_model6", "u5dr_uci_model6", "ln_u5dr_se6", "u5dr_survey_weight16", "tm")							
	
# merge mortality data with strata time series
	tst <- merge(tst, s_merge1, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge2, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge3, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge4, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge5, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge6, by=c("stratum", "tm"), all.x=TRUE)

	# make sure time series is still sorted by stratum and time
	tst <- tst[order(tst[, "stratum"], tst[, "tm"]), ]
	
	
# distribute mortality data over recall period

for (i in 1:nrow(tst) ) {

#if (i %% ( length(month) * length(year) ) == 0 ) print(tst[i, "stratum"])
	
	# for each in the duplicate columns...
	for (j in 1:6) {
	
		# if a survey was done during that month, extend estimates and confidence interval backwards over recall period
		if ( is.na(tst[i, paste("cdr_est_model", j, sep="")]) == FALSE ) {		
		
			#figure out recall period
			tr <- as.numeric(tst[i, paste("recall_months", j, sep="")] )

			# copy data for survey onto previous months within recall period
			tst[(i-tr+1):(i-1), c(paste("survey_id", j, sep="")     ,  paste("stratum_cov", j, sep="")   , 
								  paste("cdr_est_model", j, sep="") ,  paste("cdr_lci_model", j, sep=""),  paste("cdr_uci_model", j, sep="") ,
								  paste("ln_cdr_se", j, sep="") ,      paste("u5dr_est_model", j, sep=""), paste("u5dr_lci_model", j, sep="") , 
								  paste("u5dr_uci_model", j, sep="") , paste("ln_u5dr_se", j, sep="") ,
								  paste("cdr_survey_weight1", j, sep="") , paste("u5dr_survey_weight1", j, sep="")								  
								 )
			   ] <-
			tst[i             , c(paste("survey_id", j, sep="")     ,  paste("stratum_cov", j, sep="")   , 
								  paste("cdr_est_model", j, sep="") ,  paste("cdr_lci_model", j, sep=""),  paste("cdr_uci_model", j, sep="") ,
								  paste("ln_cdr_se", j, sep="") ,      paste("u5dr_est_model", j, sep=""), paste("u5dr_lci_model", j, sep="") , 
								  paste("u5dr_uci_model", j, sep="") , paste("ln_u5dr_se", j, sep="") ,
								  paste("cdr_survey_weight1", j, sep="") , paste("u5dr_survey_weight1", j, sep="")		
								 )
			   ]

			}			
		}
	}


## Anthropometry merging
	
# create anthropometry dataset for merging	
s_anthro <-       subset(s, eligible_anthropometry=="yes")[, c("survey_id", "y_survey", "m_survey", "stratum",
														"gam_whz_who", "sam_whz_who", "gam_whz_nchs", "sam_whz_nchs", "gam_muac", "sam_muac_110",
														"sam_muac_115", "oedema", "pregnant_gam_muac"
														)
												   ]

	# create time variable
	s_anthro[, "tm"]    <- (s_anthro[, "y_survey"] - year[1] ) * length(month) + s_anthro[, "m_survey"]

	#identify anthropometry duplicates (i.e. surveys that cover the same stratum and whose recall period overlaps)

	s_anthro <- s_anthro[order(s_anthro[, "stratum"], s_anthro[, "tm"], s_anthro[, "survey_id"] ), ]

	dupl_a <- rep(1, nrow(s_anthro) )

	for (i in 2:nrow(s_anthro) ) {

			if ( (s_anthro[i, "tm"] == s_anthro[i-1, "tm"]) & ((s_anthro[i, "stratum"] == s_anthro[i-1, "stratum"])) )
				dupl_a[i] <- dupl_a[i-1] + 1 else dupl_a[i] <- 1 
			
		}

	s_anthro[, "dupl"] <- dupl_a
	
	table(s_anthro[, "dupl"])

	# create separate datasets for duplicates
	s_merge1 <- subset(s_anthro, dupl==1, select=-c(dupl, y_survey, m_survey) )
	s_merge2 <- subset(s_anthro, dupl==2, select=-c(dupl, y_survey, m_survey) )
	s_merge3 <- subset(s_anthro, dupl==3, select=-c(dupl, y_survey, m_survey) )
	s_merge4 <- subset(s_anthro, dupl==4, select=-c(dupl, y_survey, m_survey) )
	s_merge5 <- subset(s_anthro, dupl==5, select=-c(dupl, y_survey, m_survey) )
	s_merge6 <- subset(s_anthro, dupl==6, select=-c(dupl, y_survey, m_survey) )
	s_merge7 <- subset(s_anthro, dupl==7, select=-c(dupl, y_survey, m_survey) )
		
	# rename columns to prepare for merging
	colnames(s_merge1) <- c("nut_survey_id1", "stratum", "gam_whz_who1", "sam_whz_who1", "gam_whz_nchs1",
							"sam_whz_nchs1", "gam_muac1", "sam_muac_1101", "sam_muac_1151", "oedema1", "pregnant_gam_muac1", "tm")
	colnames(s_merge2) <- c("nut_survey_id2", "stratum", "gam_whz_who2", "sam_whz_who2", "gam_whz_nchs2",
							"sam_whz_nchs2", "gam_muac2", "sam_muac_1102", "sam_muac_1152", "oedema2", "pregnant_gam_muac2", "tm")
	colnames(s_merge3) <- c("nut_survey_id3", "stratum", "gam_whz_who3", "sam_whz_who3", "gam_whz_nchs3",
							"sam_whz_nchs3", "gam_muac3", "sam_muac_1103", "sam_muac_1153", "oedema3", "pregnant_gam_muac3", "tm")
	colnames(s_merge4) <- c("nut_survey_id4", "stratum", "gam_whz_who4", "sam_whz_who4", "gam_whz_nchs4",
							"sam_whz_nchs4", "gam_muac4", "sam_muac_1104", "sam_muac_1154", "oedema4", "pregnant_gam_muac4", "tm")
	colnames(s_merge5) <- c("nut_survey_id5", "stratum", "gam_whz_who5", "sam_whz_who5", "gam_whz_nchs5",
							"sam_whz_nchs5", "gam_muac5", "sam_muac_1105", "sam_muac_1155", "oedema5", "pregnant_gam_muac5", "tm")
	colnames(s_merge6) <- c("nut_survey_id6", "stratum", "gam_whz_who6", "sam_whz_who6", "gam_whz_nchs6",
							"sam_whz_nchs6", "gam_muac6", "sam_muac_1106", "sam_muac_1156", "oedema6", "pregnant_gam_muac6", "tm")
	colnames(s_merge7) <- c("nut_survey_id7", "stratum", "gam_whz_who7", "sam_whz_who7", "gam_whz_nchs7",
							"sam_whz_nchs7", "gam_muac7", "sam_muac_1107", "sam_muac_1157", "oedema7", "pregnant_gam_muac7", "tm")
															
# merge anthro data with strata time series
	tst <- merge(tst, s_merge1, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge2, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge3, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge4, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge5, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge6, by=c("stratum", "tm"), all.x=TRUE)
	tst <- merge(tst, s_merge7, by=c("stratum", "tm"), all.x=TRUE)
	
	# make sure time series is still sorted by stratum and time
	tst <- tst[order(tst[, "stratum"], tst[, "tm"]), ]
												   

	
#.........................................................................................
###Save dataset

# write to file
write.csv(tst, "tseries_strata.pop3.csv" , row.names=FALSE)
	
	
#tst<-read.csv("tseries_strata.pop3.csv")


#.........................................................................................
### Add stratum population figures for Somalia and Ethiopia

tst <- merge(tst, pop3, by=c("stratum", "tm"), all.x=TRUE)

# fill in missing figures for April-November 2010 monthly strata in Somalia (back-calculate from earliest month with population data,
# assuming 2.9% yearly growth rate overall and 25% under 5s)
for (i in nrow(tst):1 ) {

	if ( (tst[i, "tm"] > 51) & (is.na(tst[i, "pop3"]) == TRUE) & (tst[i, "location"] == "Somalia") ) {
	
		tst[i, "pop3"] = tst[i+1, "pop3"] / (1 + (0.029/12) )	
	
		}
	}

tst[, "pop3"] <- round(tst[, "pop3"], 0)
	
# add under 5 population only if missing (i.e. Ethiopia, some Somalia months in 2010)
tst[, "pop3.u5"] <- ifelse(is.na(tst[, "pop3.u5"])==TRUE, 0.25 * tst[, "pop3"], tst[, "pop3.u5"] )
tst[, "pop3.u5"] <- round(tst[, "pop3.u5"], 0)


# add Kenya refugee populations
tst <- merge(tst, pop3_kenya, by=c("stratum", "tm"), all.x=TRUE)
tst[, "pop3_1to2.u5"] <- 0.25 * tst[, "pop3_1to2"]
tst[, "pop3_3to5.u5"] <- 0.25 * tst[, "pop3_3to5"]
tst[, "pop3_6to11.u5"] <- 0.25 * tst[, "pop3_6to11"]
tst[, "pop3_12plus.u5"] <- 0.25 * tst[, "pop3_12plus"]



#.........................................................................................
### Correct stratum-month mortality standard errors and calculate probabilities of selection for each survey

# compute the total person-time within the sampling frame of each survey
survey_ids <- unique(c(as.character(tst[, "survey_id1"]), as.character(tst[, "survey_id2"]),
					   as.character(tst[, "survey_id3"]), as.character(tst[, "survey_id4"]),
					   as.character(tst[, "survey_id5"]), as.character(tst[, "survey_id6"])
					   )
					 )

survey_ids <- na.omit(survey_ids)

					 
# person-time for CDR
survey_ptimes <- c()

for (i in survey_ids) {

		survey_ptimes <- c(survey_ptimes, 
						   sum( subset(tst, survey_id1==i)[, "stratum_cov1"] * subset(tst, survey_id1==i)[, "pop3"] * 30.42, na.rm=TRUE) + 
						   sum( subset(tst, survey_id2==i)[, "stratum_cov2"] * subset(tst, survey_id2==i)[, "pop3"] * 30.42, na.rm=TRUE) + 
						   sum( subset(tst, survey_id3==i)[, "stratum_cov3"] * subset(tst, survey_id3==i)[, "pop3"] * 30.42, na.rm=TRUE) + 
						   sum( subset(tst, survey_id4==i)[, "stratum_cov4"] * subset(tst, survey_id4==i)[, "pop3"] * 30.42, na.rm=TRUE) + 
						   sum( subset(tst, survey_id5==i)[, "stratum_cov5"] * subset(tst, survey_id5==i)[, "pop3"] * 30.42, na.rm=TRUE) + 
						   sum( subset(tst, survey_id6==i)[, "stratum_cov6"] * subset(tst, survey_id6==i)[, "pop3"] * 30.42, na.rm=TRUE)
						   )
	}

# person-time for U5DR	
survey_ptimes.u5 <- c()
	
for (i in survey_ids) {

		survey_ptimes.u5 <- c(survey_ptimes.u5, 
						      sum( subset(tst, survey_id1==i)[, "stratum_cov1"] * subset(tst, survey_id1==i)[, "pop3.u5"] * 30.42, na.rm=TRUE) + 
						      sum( subset(tst, survey_id2==i)[, "stratum_cov2"] * subset(tst, survey_id2==i)[, "pop3.u5"] * 30.42, na.rm=TRUE) + 
						      sum( subset(tst, survey_id3==i)[, "stratum_cov3"] * subset(tst, survey_id3==i)[, "pop3.u5"] * 30.42, na.rm=TRUE) + 
						      sum( subset(tst, survey_id4==i)[, "stratum_cov4"] * subset(tst, survey_id4==i)[, "pop3.u5"] * 30.42, na.rm=TRUE) + 
						      sum( subset(tst, survey_id5==i)[, "stratum_cov5"] * subset(tst, survey_id5==i)[, "pop3.u5"] * 30.42, na.rm=TRUE) + 
						      sum( subset(tst, survey_id6==i)[, "stratum_cov6"] * subset(tst, survey_id6==i)[, "pop3.u5"] * 30.42, na.rm=TRUE)
						   )
	}

# merging person-time with survey dataset
survey_ptime <- data.frame(survey_ids, survey_ptimes, survey_ptimes.u5)
colnames(survey_ptime) <- c("survey_id", "survey_ptime", "survey_ptime.u5")	

surveys <- merge(surveys, survey_ptime, by="survey_id", all.x=TRUE)

	
# function to resize standard errors based on the fraction of survey person-time represented by the stratum-month
f.se.correct.cdr <- function(f.tst, f.surveys) {

	return (c(
			  ifelse(is.na ( f.tst[["stratum_cov1"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se1"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id1"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov1"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov2"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se2"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id2"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov2"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov3"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se3"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id3"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov3"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov4"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se4"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id4"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov4"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov5"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se5"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id5"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov5"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov6"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_cdr_se6"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id6"]])[, "survey_ptime"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3"]] ) * as.numeric( f.tst[["stratum_cov6"]] ) * 30.42 )
					) 
			)
		   )

	}

f.se.correct.u5dr <- function(f.tst, f.surveys) {

	return (c(
			  ifelse(is.na ( f.tst[["stratum_cov1"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se1"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id1"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov1"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov2"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se2"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id2"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov2"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov3"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se3"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id3"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov3"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov4"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se4"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id4"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov4"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov5"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se5"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id5"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov5"]] ) * 30.42 )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov6"]] ) == TRUE, 
					 "",
					 as.numeric( f.tst[["ln_u5dr_se6"]]) * sqrt(as.numeric( subset(f.surveys, survey_id==f.tst[["survey_id6"]])[, "survey_ptime.u5"] ) ) /
					 sqrt( as.numeric( f.tst[["pop3.u5"]] ) * as.numeric( f.tst[["stratum_cov6"]] ) * 30.42 )
					) 
			)
		   )

	}

# correct SEs for CDR
tst[, c("ln_cdr_se_adj1", "ln_cdr_se_adj2", "ln_cdr_se_adj3", "ln_cdr_se_adj4", "ln_cdr_se_adj5", "ln_cdr_se_adj6")] <- 
   t(apply(tst, 1, f.se.correct.cdr, surveys) )	
# correct SEs for U5DR
tst[, c("ln_u5dr_se_adj1", "ln_u5dr_se_adj2", "ln_u5dr_se_adj3", "ln_u5dr_se_adj4", "ln_u5dr_se_adj5", "ln_u5dr_se_adj6")] <- 
   t(apply(tst, 1, f.se.correct.u5dr, surveys) )	
	
	
# function to calculate a probability of selection for each survey covering a given stratum-month
f.svy.prob.cdr <- function(f.tst, f.surveys) {

	return (c(
			  ifelse(is.na ( f.tst[["stratum_cov1"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight11"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov1"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id1"]])[, "survey_ptime"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov2"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight12"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov2"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id2"]])[, "survey_ptime"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov3"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight13"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov3"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id3"]])[, "survey_ptime"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov4"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight14"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov4"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id4"]])[, "survey_ptime"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov5"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight15"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov5"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id5"]])[, "survey_ptime"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov6"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["cdr_survey_weight16"]]) * ( as.numeric(f.tst[["pop3"]]) * as.numeric(f.tst[["stratum_cov6"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id6"]])[, "survey_ptime"] )
					)					
			)
		   )

	}	

f.svy.prob.u5dr <- function(f.tst, f.surveys) {

	return (c(
			  ifelse(is.na ( f.tst[["stratum_cov1"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight11"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov1"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id1"]])[, "survey_ptime.u5"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov2"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight12"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov2"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id2"]])[, "survey_ptime.u5"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov3"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight13"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov3"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id3"]])[, "survey_ptime.u5"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov4"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight14"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov4"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id4"]])[, "survey_ptime.u5"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov5"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight15"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov5"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id5"]])[, "survey_ptime.u5"] )
					) ,
			  ifelse(is.na ( f.tst[["stratum_cov6"]] ) == TRUE, 
					 0,
					 as.numeric(f.tst[["u5dr_survey_weight16"]]) * ( as.numeric(f.tst[["pop3.u5"]]) * as.numeric(f.tst[["stratum_cov6"]] ) * 30.42 ) /
					 as.numeric(subset(f.surveys, survey_id==f.tst[["survey_id6"]])[, "survey_ptime.u5"] )
					)		
			)
		   )

	}

# calculate selection probabilities for CDR
tst[, c("cdr_survey_prob1", "cdr_survey_prob2", "cdr_survey_prob3", "cdr_survey_prob4", "cdr_survey_prob5", "cdr_survey_prob6")] <-
  t(apply(tst, 1, f.svy.prob.cdr, surveys) )	
tst[, "cdr_survey_prob_tot"] <- tst[, "cdr_survey_prob1"] + tst[, "cdr_survey_prob2"] + tst[, "cdr_survey_prob3"] +
                                tst[, "cdr_survey_prob4"] + tst[, "cdr_survey_prob5"] + tst[, "cdr_survey_prob6"]
tst[, "cdr_survey_prob1"] <- tst[, "cdr_survey_prob1"] / tst[, "cdr_survey_prob_tot"]
tst[, "cdr_survey_prob2"] <- tst[, "cdr_survey_prob2"] / tst[, "cdr_survey_prob_tot"]
tst[, "cdr_survey_prob3"] <- tst[, "cdr_survey_prob3"] / tst[, "cdr_survey_prob_tot"]
tst[, "cdr_survey_prob4"] <- tst[, "cdr_survey_prob4"] / tst[, "cdr_survey_prob_tot"]
tst[, "cdr_survey_prob5"] <- tst[, "cdr_survey_prob5"] / tst[, "cdr_survey_prob_tot"]
tst[, "cdr_survey_prob6"] <- tst[, "cdr_survey_prob6"] / tst[, "cdr_survey_prob_tot"]

# calculate selection probabilities for U5DR
tst[, c("u5dr_survey_prob1", "u5dr_survey_prob2", "u5dr_survey_prob3", "u5dr_survey_prob4", "u5dr_survey_prob5", "u5dr_survey_prob6")] <-
  t(apply(tst, 1, f.svy.prob.u5dr, surveys) )	
tst[, "u5dr_survey_prob_tot"] <- tst[, "u5dr_survey_prob1"] + tst[, "u5dr_survey_prob2"] + tst[, "u5dr_survey_prob3"] +
                                 tst[, "u5dr_survey_prob4"] + tst[, "u5dr_survey_prob5"] + tst[, "u5dr_survey_prob6"]
tst[, "u5dr_survey_prob1"] <- tst[, "u5dr_survey_prob1"] / tst[, "u5dr_survey_prob_tot"]
tst[, "u5dr_survey_prob2"] <- tst[, "u5dr_survey_prob2"] / tst[, "u5dr_survey_prob_tot"]
tst[, "u5dr_survey_prob3"] <- tst[, "u5dr_survey_prob3"] / tst[, "u5dr_survey_prob_tot"]
tst[, "u5dr_survey_prob4"] <- tst[, "u5dr_survey_prob4"] / tst[, "u5dr_survey_prob_tot"]
tst[, "u5dr_survey_prob5"] <- tst[, "u5dr_survey_prob5"] / tst[, "u5dr_survey_prob_tot"]
tst[, "u5dr_survey_prob6"] <- tst[, "u5dr_survey_prob6"] / tst[, "u5dr_survey_prob_tot"]

# sort time series again
tst <- tst[order(tst[, "stratum"], tst[, "tm"]), ]

#.........................................................................................
### Add projected optimistic and pessimistic death rates for refugee camps

tst <- merge(tst, refugee.mortality, by=c("y", "m", "stratum"), all.x=TRUE)


#.........................................................................................
### Visualise food security indices, malnutrition prevalence and CDR/U5DR over time across strata

# restrict dataset to Somalia
tst.som <- subset(tst, location=="Somalia")

# pick fixed y axis limits for all graphs
ylim.RToT <- 2
ylim.AToTw <- quantile(tst.som[, "AToTw"], c(0.95) , na.rm=TRUE )
ylim.AToTg <- quantile(tst.som[, "AToTg"], c(0.95) , na.rm=TRUE )
ylim.cpi <- 4
ylim.cdr <- quantile(c(tst.som$cdr_uci_model1, tst.som$cdr_uci_model2, tst.som$cdr_uci_model3,
				        tst.som$cdr_uci_model4, tst.som$cdr_uci_model5, tst.som$cdr_uci_model6), na.rm=TRUE, c(0.95) )
ylim.gam <- max(c(tst.som$gam_muac1, tst.som$gam_muac2, tst.som$gam_muac3, tst.som$gam_muac4, 
				  tst.som$gam_muac5, tst.som$gam_muac6, tst.som$gam_muac7), na.rm=TRUE) * 1.1

# for each stratum...				  
for (i in c(unique(as.character(tst.som[, "stratum"])) ) ) {

	# capture data for that stratum
	dat <- subset(tst.som, stratum==i)

	# set general plot parameters
	par(mar=c(6, 10, 3, 8) + 0.1)
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")

	# plot RToT
	if (dat[1, "livelihood"] == "pastoral" ) {		
		# if pastoralists...
		plot(dat$tm, dat$RToTg, axes=F, ylim=c(0, ylim.RToT), xlab="", ylab="", type="l", col="cadetblue4", lty=3,
			 main=paste(dat[1, "region"], "-", dat[1, "livelihood"], sep=""), xlim=c(6, 79) , lwd=2)
		axis(2, ylim=c(0, ylim.RToT), col="cadetblue4", lwd=2)
		mtext(2,text="terms of trade relative to baseline", line=2)
	}
	else
	{
		# ...otherwise
		plot(dat$tm, dat$RToTw, axes=F, ylim=c(0, ylim.RToT), xlab="", ylab="", type="l", col="cadetblue4", lty=3,
			 main=paste(dat[1, "region"], "-", dat[1, "livelihood"], sep=""), xlim=c(6, 79) , lwd=2)
		axis(2, ylim=c(0, ylim.RToT), col="cadetblue4", lwd=2)
		mtext(2,text="terms of trade relative to baseline", line=2)
	}

	#plot AToT
	par(new=T)
	if (dat[1, "livelihood"] == "pastoral" ) {		
		# if pastoralists...
		plot(dat$tm, dat$AToTg, axes=F, ylim=c(0, ylim.AToTg), xlab="", ylab="", type="l", col="mediumpurple3", lty=1,
			 main="", xlim=c(6, 79) , lwd=2)
		axis(2, ylim=c(0, ylim.AToTg), col="mediumpurple3", lwd=2, line=3.5)
		mtext(2, text="absolute terms of trade (Kcal cereals per goat sold)", line=5.5)
	}
	else
	{
		# ...otherwise
		plot(dat$tm, dat$AToTw, axes=F, ylim=c(0, ylim.AToTw), xlab="", ylab="", type="l", col="mediumpurple3", lty=1,
			 main="", xlim=c(6, 79) , lwd=2)
		axis(2, ylim=c(0, ylim.AToTw), col="mediumpurple3", lwd=2, line=3.5)
		mtext(2, text="absolute terms of trade (Kcal cereals per daily wage)", line=5.5)
	}
	
	#plot CPI
	if (length(na.omit(dat$s_cpi)) != 0 ) {

		par(new=T)
		plot(dat$tm, dat$s_cpi, axes=F, ylim=c(0, ylim.cpi), xlab="", ylab="", type="l", col="dodgerblue4", lty=4,
			 main="", xlim=c(6, 79) , lwd=3)
		axis(2, ylim=c(0, ylim.cpi), col="dodgerblue4", lwd=2, line=7)
		mtext(2, text="Consumer Price Index (relative to baseline)", line=9)
	}
	
	#plot CDR
	if (length(na.omit(dat$cdr_est_model1)) != 0 ) {
			
		par(new=T)
		plot(dat$tm, dat$cdr_est_model1, axes=F, ylim=c(0, ylim.cdr), xlab="", ylab="", type="l", col="darkred", lty=1, lwd=10, main="", xlim=c(6, 79) )
		lines(dat$tm, dat$cdr_est_model2, type="l", col="darkred", lty=1, lwd=10 )
		lines(dat$tm, dat$cdr_est_model3, type="l", col="darkred", lty=1, lwd=10 )
		lines(dat$tm, dat$cdr_est_model4, type="l", col="darkred", lty=1, lwd=10 )
		lines(dat$tm, dat$cdr_est_model5, type="l", col="darkred", lty=1, lwd=10 )
		lines(dat$tm, dat$cdr_est_model6, type="l", col="darkred", lty=1, lwd=10 )
		lines(dat$tm, dat$cdr_uci_model1, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_uci_model2, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_uci_model3, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_uci_model4, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_uci_model5, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_uci_model6, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model1, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model2, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model3, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model4, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model5, type="l", col="darkred", lty=1, lwd=1 )
		lines(dat$tm, dat$cdr_lci_model6, type="l", col="darkred", lty=1, lwd=1 )
		axis(4, ylim=c(0, ylim.cdr), col="darkred", lwd=2)
		mtext(4, text="crude death rate (per 10 000 person-days)", line=2)
	}

	#plot GAM MUAC
	if (length(na.omit(dat$gam_muac1)) != 0 ) {

		par(new=T)
		plot(dat$tm, dat$gam_muac1, axes=F, ylim=c(0, ylim.gam), xlab="", ylab="", type="l", col="tan4", lty=0, lwd=5, main="", xlim=c(6, 79) )
		points(dat$tm, dat$gam_muac1, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac2, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac3, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac4, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac5, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac6, col="tan4", bg="orange2", pch=24, cex=1.5) 
		points(dat$tm, dat$gam_muac7, col="tan4", bg="orange2", pch=24, cex=1.5) 
		axis(4, ylim=c(0, ylim.gam), col="orange2", lwd=2, line=3.5)
		mtext(4, text="% GAM prevalence (MUAC < 125mm and/or oedema)", line=5.5)
	}

	# add x axis
	par(new=T)
	axis(1, at=seq(7, 79 , by=3), col="black", labels=FALSE)
	
		# add x axis labels
		lablist <- c("Jul-2006", "Oct-2006", "Jan-2007", "Apr-2007", "Jul-2007", "Oct-2007", "Jan-2008", "Apr-2008", "Jul-2008", "Oct-2008",  "Jan-2009", 
					 "Apr-2009", "Jul-2009", "Oct-2009", "Jan-2010", "Apr-2010", "Jul-2010", "Oct-2010",  "Jan-2011", "Apr-2011", "Jul-2011", "Oct-2011",
					 "Jan-2012", "Apr-2012", "Jul-2012")
		text(seq(7, 79 , by=3),  par("usr")[3] - 3, labels = lablist, srt = 45, pos = 1, xpd = TRUE)
		mtext("month-year", side=1, col="black", line=4)	

		# add ablines for each year
		abline(v=seq(1, 73, 12), lty=3, col="grey")

	# add the legend
	legend(x="top", legend=c("relative terms of trade", "absolute terms of trade", "Consumer Price Index", "CDR point estimate", "CDR 95% CI", "GAM prevalence"),
		   lty=c(3, 1, 4, 1, 1, 0), col=c("cadetblue4", "mediumpurple3", "dodgerblue4", "darkred", "darkred", "tan4"), pt.bg=c(NA, NA, NA, NA, NA, "orange2"),
		   pch=c(NA, NA, NA, NA, NA, 24), pt.cex=c(1, 1, 1, 1, 1, 1.5), lwd=c(2, 2, 2, 10, 1, NA), ncol=2, bty="n" )
		
	Sys.sleep(3)

	}

	

#.........................................................................................
### Define start and end of analysis period for each stratum
		
# visualise time series of RToT_liv in each stratum so as to define start and end

	tst.som <- subset(tst, location=="Somalia")

	# set general plot parameters
	par(mar=c(5, 4, 2, 2) + 0.1)
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	
	# plot RToTw_liv in other strata one by one
		for (i in c(unique(as.character(tst.som[, "stratum"])) ) ) {

			dat <- subset(tst.som, stratum==i)
			plot(dat$tm, dat$RToT_liv, axes=F, ylim=c(0, 2.5), xlab="", ylab="", type="l", col="cadetblue4", lty=1,
				 main=dat[1, "stratum"], xlim=c(6, 79) , lwd=1)
			axis(2, ylim=c(0, 2.5), lwd=1)
			mtext(2, text="relative terms of trade", line=2)

			# add horizontal ablines
			abline(h = seq(0, 2.5, 0.1), lty=3, col="grey")

			axis(1, at=seq(7, 79 , by=1), col="black", labels=FALSE)
	
			# add x axis labels
			lablist <- seq(7, 79, by=2)
			text(seq(7, 79 , by=2),  par("usr")[3] + 0.2 , labels = lablist, srt = 0, pos = 1, cex=0.8 , xpd = TRUE)
			mtext("month", side=1, col="black", line=3.3)	

			# add ablines for each month
			abline(v=seq(7, 79, 1), lty=3, col="grey")
			abline(v=seq(7, 79, 12), lty=3, col="black")
	
			Sys.sleep(8)
		}


## visualise time series of RToT_liv in each stratum superimposed (graph for report)

	# set general plot parameters
	par(mar=c(5, 4, 2, 2) + 0.1)
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")

	# plot first stratum	
	dat <- subset(tst.som, stratum==unique(as.character(tst.som[, "stratum"]))[1] )
	plot(dat$tm, dat$RToT_liv, axes=F, ylim=c(0, 3.2), xlab="", ylab="", type="l", col="cadetblue4", lty=1,
		 main="", xlim=c(6, 79) , lwd=1)
	axis(2, ylim=c(0, 3.2), lwd=1)
	mtext(2, text="terms of trade relative to the start of the time series", line=2)
	
	# plot other strata one by one
		for (i in c(unique(as.character(tst.som[, "stratum"])) ) ) {

			dat <- subset(tst.som, stratum==i)
			lines(dat$tm, dat$RToT_liv, type="l", col="cadetblue4", lty=1, lwd=1 )
		}

	# add x axis
	axis(1, at=seq(7, 79 , by=3), col="black", labels=FALSE)
	
		# add x axis labels
		lablist <- c("Jul-2006", "Oct-2006", "Jan-2007", "Apr-2007", "Jul-2007", "Oct-2007", "Jan-2008", "Apr-2008", "Jul-2008", "Oct-2008",  "Jan-2009", 
					 "Apr-2009", "Jul-2009", "Oct-2009", "Jan-2010", "Apr-2010", "Jul-2010", "Oct-2010",  "Jan-2011", "Apr-2011", "Jul-2011", "Oct-2011",
					 "Jan-2012", "Apr-2012", "Jul-2012")
		text(seq(7, 79 , by=3),  par("usr")[3] - 0.2 , labels = lablist, srt = 45, pos = 1, xpd = TRUE)
		mtext("month-year", side=1, col="black", line=3.3)	

		# add ablines for each year
		abline(v=seq(1, 73, 12), lty=3, col="grey")
	
	# add line showing baseline = 1
	lines(seq(6, 79 , by=1), rep(1, length(seq(6, 79, by=1)) ), xlim=c(6, 79), lty=2, col="blue")
	
	# add ablines showing range of analysis start months
	abline(v=c(55, 63), lty=1, col="red", lwd=2)

	# save plot
	savePlot("graph_RToT_liv_strata.wmf",type="wmf") 	

	

## add analysis period to stratum time series

out <- c()

for (i in c(unique(as.character(tst.som[, "stratum"])) ) ) {

	out_i <- rep(0, 84)
	# if stopping period at 6mo after return to baseline
	#out_i[ subset(strata, stratum==i)$tm_crisis_start : min(79, subset(strata, stratum==i)$tm_crisis_end) ] <- 1
	
	# if going to July 2012 for all strata
	out_i[ subset(strata, stratum==i)$tm_crisis_start : 79 ] <- 1	
	
	out <- c(out, out_i)
	
	}

# sort time series again
tst.som <- tst.som[order(tst.som[, "stratum"], tst.som[, "tm"]), ]

tst.som[, "period"] <- out	
tst <- merge(tst, tst.som[, c("stratum", "tm", "period")], by=c("stratum", "tm"), all.x=TRUE)


# median and range period
periods <-c()

for (i in c(unique(as.character(tst.som[, "stratum"])) ) ) {
	
	# figure out length of period
	periods_i <- nrow(subset(tst.som, stratum==i & period==1))

	periods <- c(periods, periods_i)
	
	}

median(periods)
range(periods)
	
#.........................................................................................
### Define months with mortality data coverage

tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model1"])==FALSE, 1, 0)
tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model2"])==FALSE, 1, tst[ , "coverage"])
tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model3"])==FALSE, 1, tst[ , "coverage"])
tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model4"])==FALSE, 1, tst[ , "coverage"])
tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model5"])==FALSE, 1, tst[ , "coverage"])
tst[ , "coverage"] <- ifelse( is.na(tst[, "cdr_est_model6"])==FALSE, 1, tst[ , "coverage"])


# graph data coverage over analysis period for each stratum in Somalia
	tst.som <- subset(tst, location=="Somalia")

	# general parameters
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	par(mar=c(3,4,3,2) + 0.1)

	# assign value to each month in series: 0 if not in period, 1 if in period but no data, 2 if in period and data
	a <- ifelse(tst.som[, "period"] == 1, ifelse(tst.som[, "coverage"] == 1 , 2, 1) , 0 )
	mat <- matrix(a,  max(tst.som$tm), length(unique(tst.som[, "stratum"]) ) )[50:79, ]
	
	# plot matrix (1 = grey, 2 = red)
	image( mat  , col=c("white", "grey", "darkred") , ylab="" , axes=FALSE)
	grid(nrow(mat), ncol(mat))

	# add x axis
	lablist.m <- c("Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
                 "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul" )
	axis(1, at=seq(1/(nrow(mat)-1), 1, 1/(nrow(mat)-1)), col="black", labels=lablist.m, cex.axis=0.7, tick=FALSE, line=-0.8)

	lablist.y <- c("", "", "", "", "", "2010", "", "", "", "", "", "", "", "", "", "2011", "", "", "",
                 "", "", "", "", "", "", "2012", "", "", "" )		 
	axis(1, at=seq(1/(nrow(mat)-1), 1, 1/(nrow(mat)-1)), col="black", labels=lablist.y, cex.axis=0.7, tick=FALSE, line=-0)
		
	# add y axis
	lablist <- unique(paste(as.character(tst.som$region), "-", substr(tst.som$livelihood, 1, 3) , sep="") )
	axis(2, at=seq(0/(ncol(mat)-1), 1, 1/(ncol(mat)-1)), col="black", labels=lablist, cex.axis=0.7, tick=FALSE, line=-1.4, las=1)
	
	#add legend
	mtext("agr = agro-pastoralist    idp = internally displaced    pas = pastoralist    riv = riverine    urb = urban  ", side=3, col="black", line=1.3, cex=0.7)	
	
	# save plot
	savePlot("graph_mortality_data_coverage.wmf",type="wmf") 	

	
# number of surveys falling within analysis period
	length(unique(c(subset(tst, period==1)[, "cdr_est_model1"], subset(tst, period==1)[, "cdr_est_model2"], subset(tst, period==1)[, "cdr_est_model3"], 
	                subset(tst, period==1)[, "cdr_est_model4"], subset(tst, period==1)[, "cdr_est_model5"], subset(tst, period==1)[, "cdr_est_model6"] ) ) )



# graph proportion of person-time covered by data for each stratum in Somalia
	tst.analysis.som <- subset(tst, location=="Somalia")

	# select time period for which death toll totals are presented	
	out <- subset(tst.analysis.som[, c("tm", "stratum", "pop3", "coverage")], tm>57 & tm<77)
	out <-aggregate(out$pop3, list(out$stratum, out$coverage), FUN=sum, na.rm=TRUE)
	colnames(out) <- c("stratum", "coverage", "pop3")
	out <- merge( subset(out, coverage==0, select=-coverage), subset(out, coverage==1, select=-coverage), by=("stratum"), all=TRUE)
	colnames(out) <-c("stratum", "indirect", "direct")
	out <- subset(out, indirect>0)
	out[, "direct"] <- ifelse(is.na(out[, "direct"])==TRUE, 0, out[, "direct"] )	
	out[, "direct"] <- out[, "direct"] / 1000
	out[, "indirect"] <- out[, "indirect"] / 1000	
	
	# general parameters
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	par(mar=c(4,7,3,1) + 0.1, mgp=c(3,0.5,0), cex=0.9 )

	# plot horizontal bar chart
	lablist <- unique(paste(as.character(tst.analysis.som$region), "-", substr(tst.analysis.som$livelihood, 1, 3) , sep="") )
	barplot(t(cbind(out$direct, out$indirect)), horiz=TRUE, names.arg=lablist, las=1, col=c("darkred", "grey"), space = 0.5, xlim=c(0, 12000) )

	#add legend
	mtext("agr = agro-pastoralist      idp = internally displaced        pas = pastoralist", side=3, col="black", line=1.3, cex=0.9)	
	mtext("riv = riverine        urb = urban", side=3, col="black", line=0.3, cex=0.9)	

	legend(x="right", legend=c("direct estimate (survey)", "indirect estimate (model)"), fill=c("darkred", "grey"), ncol=1, bty="n")
		
	#add x axis label
	mtext("person-months (thousands)", side=1, col="black", line=1.5, cex=0.9)
	
	# save plot
	savePlot("graph_persontime_coverage.wmf",type="wmf") 	

	
					

#.........................................................................................
### Write file

# sort time series again
tst <- tst[order(tst[, "stratum"], tst[, "tm"]), ]

# write file
write.csv(tst, "tseries_strata.pop3.csv", row.names=FALSE)

	